@@ -3,7 +3,7 @@
  * Copyright (C) 1994, 1995, 1998, 1999 by IRCAM-Centre Georges Pompidou, Paris, France.
  * 
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
+ * modify it under the terms of the GNU Lesser General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
  * 
@@ -12,9 +12,9 @@
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  * 
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  * 
@@ -281,7 +281,7 @@ Nexpr_new(t_symbol *s, int ac, t_atom *av)
                 x = (t_expr *)pd_new(fexpr_tilde_class);
                 SET_FEXPR_TILDE(x);
         } else {
-                post("expr_new: bad object name '%s'");
+                post("expr_new: bad object name '%s'", s->s_name);
                 /* assume expr */
                 x = (t_expr *)pd_new(expr_class);
                 SET_EXPR(x);
@@ -833,7 +833,9 @@ expr_setup(void)
 
 
 
-        post("expr, expr~, fexpr~ version %s under GNU General Public License ", exp_version);
+        post(
+   "expr, expr~, fexpr~ version %s under GNU Lesser General Public License ",
+            exp_version);
 
 }
 
