@@ -12,6 +12,7 @@ outputs audio and messages. */
 */    
 #include "m_pd.h"
 #include "s_stuff.h"
+#include "m_imp.h"
 #include <stdio.h>
 
 #define BUFSIZE 65536
@@ -73,7 +74,7 @@ int pd_extern_sched(char *flags)
                 for (; chan < chin; chan++)
                     for (j = 0; j < DEFDACBLKSIZE; j++)
                         *fp++ = 0;
-                sched_tick(sys_time+sys_time_per_dsp_tick);
+                sched_tick();
                 sys_pollgui();
 #if defined(__linux__) || defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined(__GNU__)
                 pollwatchdog();
