@@ -132,14 +132,14 @@ static void plus_setup(void)
 {
     plus_class = class_new(gensym("+~"), (t_newmethod)plus_new, 0,
         sizeof(t_plus), 0, A_GIMME, 0);
-    class_addmethod(plus_class, (t_method)plus_dsp, gensym("dsp"), 0);
+    class_addmethod(plus_class, (t_method)plus_dsp, gensym("dsp"), A_CANT, 0);
     CLASS_MAINSIGNALIN(plus_class, t_plus, x_f);
     class_sethelpsymbol(plus_class, gensym("sigbinops"));
     scalarplus_class = class_new(gensym("+~"), 0, 0,
         sizeof(t_scalarplus), 0, 0);
     CLASS_MAINSIGNALIN(scalarplus_class, t_scalarplus, x_f);
-    class_addmethod(scalarplus_class, (t_method)scalarplus_dsp, gensym("dsp"),
-        0);
+    class_addmethod(scalarplus_class, (t_method)scalarplus_dsp,
+        gensym("dsp"), A_CANT, 0);
     class_sethelpsymbol(scalarplus_class, gensym("sigbinops"));
 }
 
@@ -263,13 +263,13 @@ static void minus_setup(void)
     minus_class = class_new(gensym("-~"), (t_newmethod)minus_new, 0,
         sizeof(t_minus), 0, A_GIMME, 0);
     CLASS_MAINSIGNALIN(minus_class, t_minus, x_f);
-    class_addmethod(minus_class, (t_method)minus_dsp, gensym("dsp"), 0);
+    class_addmethod(minus_class, (t_method)minus_dsp, gensym("dsp"), A_CANT, 0);
     class_sethelpsymbol(minus_class, gensym("sigbinops"));
     scalarminus_class = class_new(gensym("-~"), 0, 0,
         sizeof(t_scalarminus), 0, 0);
     CLASS_MAINSIGNALIN(scalarminus_class, t_scalarminus, x_f);
-    class_addmethod(scalarminus_class, (t_method)scalarminus_dsp, gensym("dsp"),
-        0);
+    class_addmethod(scalarminus_class, (t_method)scalarminus_dsp,
+        gensym("dsp"), A_CANT, 0);
     class_sethelpsymbol(scalarminus_class, gensym("sigbinops"));
 }
 
@@ -394,13 +394,13 @@ static void times_setup(void)
     times_class = class_new(gensym("*~"), (t_newmethod)times_new, 0,
         sizeof(t_times), 0, A_GIMME, 0);
     CLASS_MAINSIGNALIN(times_class, t_times, x_f);
-    class_addmethod(times_class, (t_method)times_dsp, gensym("dsp"), 0);
+    class_addmethod(times_class, (t_method)times_dsp, gensym("dsp"), A_CANT, 0);
     class_sethelpsymbol(times_class, gensym("sigbinops"));
     scalartimes_class = class_new(gensym("*~"), 0, 0,
         sizeof(t_scalartimes), 0, 0);
     CLASS_MAINSIGNALIN(scalartimes_class, t_scalartimes, x_f);
-    class_addmethod(scalartimes_class, (t_method)scalartimes_dsp, gensym("dsp"),
-        0);
+    class_addmethod(scalartimes_class, (t_method)scalartimes_dsp,
+        gensym("dsp"), A_CANT, 0);
     class_sethelpsymbol(scalartimes_class, gensym("sigbinops"));
 }
 
@@ -536,13 +536,13 @@ static void over_setup(void)
     over_class = class_new(gensym("/~"), (t_newmethod)over_new, 0,
         sizeof(t_over), 0, A_GIMME, 0);
     CLASS_MAINSIGNALIN(over_class, t_over, x_f);
-    class_addmethod(over_class, (t_method)over_dsp, gensym("dsp"), 0);
+    class_addmethod(over_class, (t_method)over_dsp, gensym("dsp"), A_CANT, 0);
     class_sethelpsymbol(over_class, gensym("sigbinops"));
     scalarover_class = class_new(gensym("/~"), 0, 0,
         sizeof(t_scalarover), 0, 0);
     CLASS_MAINSIGNALIN(scalarover_class, t_scalarover, x_f);
-    class_addmethod(scalarover_class, (t_method)scalarover_dsp, gensym("dsp"),
-        0);
+    class_addmethod(scalarover_class, (t_method)scalarover_dsp,
+        gensym("dsp"), A_CANT, 0);
     class_sethelpsymbol(scalarover_class, gensym("sigbinops"));
 }
 
@@ -678,13 +678,13 @@ static void max_setup(void)
     max_class = class_new(gensym("max~"), (t_newmethod)max_new, 0,
         sizeof(t_max), 0, A_GIMME, 0);
     CLASS_MAINSIGNALIN(max_class, t_max, x_f);
-    class_addmethod(max_class, (t_method)max_dsp, gensym("dsp"), 0);
+    class_addmethod(max_class, (t_method)max_dsp, gensym("dsp"), A_CANT, 0);
     class_sethelpsymbol(max_class, gensym("sigbinops"));
     scalarmax_class = class_new(gensym("max~"), 0, 0,
         sizeof(t_scalarmax), 0, 0);
     CLASS_MAINSIGNALIN(scalarmax_class, t_scalarmax, x_f);
-    class_addmethod(scalarmax_class, (t_method)scalarmax_dsp, gensym("dsp"),
-        0);
+    class_addmethod(scalarmax_class, (t_method)scalarmax_dsp,
+        gensym("dsp"), A_CANT, 0);
     class_sethelpsymbol(scalarmax_class, gensym("sigbinops"));
 }
 
@@ -820,13 +820,13 @@ static void min_setup(void)
     min_class = class_new(gensym("min~"), (t_newmethod)min_new, 0,
         sizeof(t_min), 0, A_GIMME, 0);
     CLASS_MAINSIGNALIN(min_class, t_min, x_f);
-    class_addmethod(min_class, (t_method)min_dsp, gensym("dsp"), 0);
+    class_addmethod(min_class, (t_method)min_dsp, gensym("dsp"), A_CANT, 0);
     class_sethelpsymbol(min_class, gensym("sigbinops"));
     scalarmin_class = class_new(gensym("min~"), 0, 0,
         sizeof(t_scalarmin), 0, 0);
     CLASS_MAINSIGNALIN(scalarmin_class, t_scalarmin, x_f);
-    class_addmethod(scalarmin_class, (t_method)scalarmin_dsp, gensym("dsp"),
-        0);
+    class_addmethod(scalarmin_class, (t_method)scalarmin_dsp,
+        gensym("dsp"), A_CANT, 0);
     class_sethelpsymbol(scalarmin_class, gensym("sigbinops"));
 }
 
