@@ -134,7 +134,7 @@ static void sigdelwrite_setup(void)
         sizeof(t_sigdelwrite), 0, A_DEFSYM, A_DEFFLOAT, 0);
     CLASS_MAINSIGNALIN(sigdelwrite_class, t_sigdelwrite, x_f);
     class_addmethod(sigdelwrite_class, (t_method)sigdelwrite_dsp,
-        gensym("dsp"), 0);
+        gensym("dsp"), A_CANT, 0);
 }
 
 /* ----------------------------- delread~ ----------------------------- */
@@ -227,7 +227,7 @@ static void sigdelread_setup(void)
         (t_newmethod)sigdelread_new, 0,
         sizeof(t_sigdelread), 0, A_DEFSYM, A_DEFFLOAT, 0);
     class_addmethod(sigdelread_class, (t_method)sigdelread_dsp,
-        gensym("dsp"), 0);
+        gensym("dsp"), A_CANT, 0);
     class_addfloat(sigdelread_class, (t_method)sigdelread_float);
 }
 
@@ -247,7 +247,6 @@ typedef struct _sigvd
 static void *sigvd_new(t_symbol *s)
 {
     t_sigvd *x = (t_sigvd *)pd_new(sigvd_class);
-    if (!*s->s_name) s = gensym("vd~");
     x->x_sym = s;
     x->x_sr = 1;
     x->x_zerodel = 0;
@@ -312,14 +311,15 @@ static void sigvd_dsp(t_sigvd *x, t_signal **sp)
             sp[0]->s_vec, sp[1]->s_vec,
                 &delwriter->x_cspace, x, sp[0]->s_n);
     }
-    else error("vd~: %s: no such delwrite~",x->x_sym->s_name);
+    else if (*x->x_sym->s_name)
+        error("vd~: %s: no such delwrite~",x->x_sym->s_name);
 }
 
 static void sigvd_setup(void)
 {
     sigvd_class = class_new(gensym("vd~"), (t_newmethod)sigvd_new, 0,
         sizeof(t_sigvd), 0, A_DEFSYM, 0);
-    class_addmethod(sigvd_class, (t_method)sigvd_dsp, gensym("dsp"), 0);
+    class_addmethod(sigvd_class, (t_method)sigvd_dsp, gensym("dsp"), A_CANT, 0);
     CLASS_MAINSIGNALIN(sigvd_class, t_sigvd, x_f);
 }
 
