@@ -11,8 +11,10 @@ Copyright:
     You may use, copy, modify this code for any purpose and 
     without fee. You may distribute this ORIGINAL package.
 
-After the following prologue, the code is exactly Ooura's original, which I
-believe the above notice permits me to redistribute.  See Ooura's website
+After the following prologue, the code is essentially Ooura's original, which I
+believe the above notice permits me to redistribute; the only change is to
+replace 'double' with a macro, 'FFTFLT', so that it can optionally
+be run in single precision for greater speed.  See Ooura's website
 for another, more permissive-sounding copyright notice.  -MSP
 */
 
@@ -28,8 +30,8 @@ for another, more permissive-sounding copyright notice.  -MSP
 #endif                      /* end alloca() ifdef nonsense */
 
 #define FFTFLT double
-void cdft(int, int, double *, int *, double *);
-void rdft(int, int, double *, int *, double *);
+void cdft(int, int, FFTFLT *, int *, FFTFLT *);
+void rdft(int, int, FFTFLT *, int *, FFTFLT *);
 
 int ilog2(int n);
 
@@ -45,13 +47,12 @@ static int ooura_init( int n)
         return (0);
     if (n > ooura_maxn)
     {
-        post("init");
         if (ooura_maxn)
         {
             t_freebytes(ooura_bitrev, ooura_bitrevsize);
             t_freebytes(ooura_costab, ooura_maxn * sizeof(FFTFLT) / 2);
         }
-        ooura_bitrevsize = sizeof(int *) * (2 + (1 << (ilog2(n)/2)));
+        ooura_bitrevsize = sizeof(int) * (2 + (1 << (ilog2(n)/2)));
         ooura_bitrev = (int *)t_getbytes(ooura_bitrevsize);
         ooura_bitrev[0] = 0;
         if (!ooura_bitrev)
@@ -85,7 +86,7 @@ EXTERN void mayer_dofft(t_sample *fz1, t_sample *fz2, int n, int sgn)
     int i;
     t_sample *fp1, *fp2;
     buf = alloca(n * (2 * sizeof(FFTFLT)));
-    if (!ooura_init(n))
+    if (!ooura_init(2*n))
         return;
     for (i = 0, fp1 = fz1, fp2 = fz2, fp3 = buf; i < n; i++)
     {
@@ -148,6 +149,22 @@ EXTERN void mayer_realifft(int n, t_sample *fz)
         fz[i] = 2*buf[i];
 }
 
+    /* ancient ISPW-like version, used in fiddle~ and perhaps other externs
+    here and there. */
+void pd_fft(t_float *buf, int npoints, int inverse)
+{
+    FFTFLT *buf2 = (FFTFLT *)alloca(2 * npoints * sizeof(FFTFLT)), *bp2;
+    t_float *fp;
+    int i;
+    if (!ooura_init(2*npoints))
+        return;
+    for (i = 0, bp2 = buf2, fp = buf; i < 2 * npoints; i++, bp2++, fp++)
+        *bp2 = *fp;
+    cdft(2*npoints, (inverse ? 1 : -1), buf2, ooura_bitrev, ooura_costab);
+    for (i = 0, bp2 = buf2, fp = buf; i < 2 * npoints; i++, bp2++, fp++)
+        *fp = *bp2;
+}
+
 /****************** end Pd-specific prologue ***********************/
 /*
 Fast Fourier/Cosine/Sine Transform
@@ -165,12 +182,12 @@ functions
     dfct: Cosine Transform of RDFT (Real Symmetric DFT)
     dfst: Sine Transform of RDFT (Real Anti-symmetric DFT)
 function prototypes
-    void cdft(int, int, double *, int *, double *);
-    void rdft(int, int, double *, int *, double *);
-    void ddct(int, int, double *, int *, double *);
-    void ddst(int, int, double *, int *, double *);
-    void dfct(int, double *, double *, int *, double *);
-    void dfst(int, double *, double *, int *, double *);
+    void cdft(int, int, FFTFLT *, int *, FFTFLT *);
+    void rdft(int, int, FFTFLT *, int *, FFTFLT *);
+    void ddct(int, int, FFTFLT *, int *, FFTFLT *);
+    void ddst(int, int, FFTFLT *, int *, FFTFLT *);
+    void dfct(int, FFTFLT *, FFTFLT *, int *, FFTFLT *);
+    void dfst(int, FFTFLT *, FFTFLT *, int *, FFTFLT *);
 macro definitions
     USE_CDFT_PTHREADS : default=not defined
         CDFT_THREADS_BEGIN_N  : must be >= 512, default=8192
@@ -197,7 +214,7 @@ macro definitions
     [parameters]
         2*n            :data length (int)
                         n >= 1, n = power of 2
-        a[0...2*n-1]   :input/output data (double *)
+        a[0...2*n-1]   :input/output data (FFTFLT *)
                         input data
                             a[2*j] = Re(x[j]), 
                             a[2*j+1] = Im(x[j]), 0<=j<n
@@ -210,7 +227,7 @@ macro definitions
                         length of ip >= 
                             2+(1<<(int)(log(n+0.5)/log(2))/2).
                         ip[0],ip[1] are pointers of the cos/sin table.
-        w[0...n/2-1]   :cos/sin table (double *)
+        w[0...n/2-1]   :cos/sin table (FFTFLT *)
                         w[],ip[] are initialized if ip[0] == 0.
     [remark]
         Inverse of 
@@ -242,7 +259,7 @@ macro definitions
     [parameters]
         n              :data length (int)
                         n >= 2, n = power of 2
-        a[0...n-1]     :input/output data (double *)
+        a[0...n-1]     :input/output data (FFTFLT *)
                         <case1>
                             output data
                                 a[2*k] = R[k], 0<=k<n/2
@@ -259,7 +276,7 @@ macro definitions
                         length of ip >= 
                             2+(1<<(int)(log(n/2+0.5)/log(2))/2).
                         ip[0],ip[1] are pointers of the cos/sin table.
-        w[0...n/2-1]   :cos/sin table (double *)
+        w[0...n/2-1]   :cos/sin table (FFTFLT *)
                         w[],ip[] are initialized if ip[0] == 0.
     [remark]
         Inverse of 
@@ -288,7 +305,7 @@ macro definitions
     [parameters]
         n              :data length (int)
                         n >= 2, n = power of 2
-        a[0...n-1]     :input/output data (double *)
+        a[0...n-1]     :input/output data (FFTFLT *)
                         output data
                             a[k] = C[k], 0<=k<n
         ip[0...*]      :work area for bit reversal (int *)
@@ -297,7 +314,7 @@ macro definitions
                         length of ip >= 
                             2+(1<<(int)(log(n/2+0.5)/log(2))/2).
                         ip[0],ip[1] are pointers of the cos/sin table.
-        w[0...n*5/4-1] :cos/sin table (double *)
+        w[0...n*5/4-1] :cos/sin table (FFTFLT *)
                         w[],ip[] are initialized if ip[0] == 0.
     [remark]
         Inverse of 
@@ -327,7 +344,7 @@ macro definitions
     [parameters]
         n              :data length (int)
                         n >= 2, n = power of 2
-        a[0...n-1]     :input/output data (double *)
+        a[0...n-1]     :input/output data (FFTFLT *)
                         <case1>
                             input data
                                 a[j] = A[j], 0<j<n
@@ -344,7 +361,7 @@ macro definitions
                         length of ip >= 
                             2+(1<<(int)(log(n/2+0.5)/log(2))/2).
                         ip[0],ip[1] are pointers of the cos/sin table.
-        w[0...n*5/4-1] :cos/sin table (double *)
+        w[0...n*5/4-1] :cos/sin table (FFTFLT *)
                         w[],ip[] are initialized if ip[0] == 0.
     [remark]
         Inverse of 
@@ -367,17 +384,17 @@ macro definitions
     [parameters]
         n              :data length - 1 (int)
                         n >= 2, n = power of 2
-        a[0...n]       :input/output data (double *)
+        a[0...n]       :input/output data (FFTFLT *)
                         output data
                             a[k] = C[k], 0<=k<=n
-        t[0...n/2]     :work area (double *)
+        t[0...n/2]     :work area (FFTFLT *)
         ip[0...*]      :work area for bit reversal (int *)
                         length of ip >= 2+sqrt(n/4)
                         strictly, 
                         length of ip >= 
                             2+(1<<(int)(log(n/4+0.5)/log(2))/2).
                         ip[0],ip[1] are pointers of the cos/sin table.
-        w[0...n*5/8-1] :cos/sin table (double *)
+        w[0...n*5/8-1] :cos/sin table (FFTFLT *)
                         w[],ip[] are initialized if ip[0] == 0.
     [remark]
         Inverse of 
@@ -403,18 +420,18 @@ macro definitions
     [parameters]
         n              :data length + 1 (int)
                         n >= 2, n = power of 2
-        a[0...n-1]     :input/output data (double *)
+        a[0...n-1]     :input/output data (FFTFLT *)
                         output data
                             a[k] = S[k], 0<k<n
                         (a[0] is used for work area)
-        t[0...n/2-1]   :work area (double *)
+        t[0...n/2-1]   :work area (FFTFLT *)
         ip[0...*]      :work area for bit reversal (int *)
                         length of ip >= 2+sqrt(n/4)
                         strictly, 
                         length of ip >= 
                             2+(1<<(int)(log(n/4+0.5)/log(2))/2).
                         ip[0],ip[1] are pointers of the cos/sin table.
-        w[0...n*5/8-1] :cos/sin table (double *)
+        w[0...n*5/8-1] :cos/sin table (FFTFLT *)
                         w[],ip[] are initialized if ip[0] == 0.
     [remark]
         Inverse of 
@@ -433,11 +450,11 @@ Appendix :
 */
 
 
-void cdft(int n, int isgn, double *a, int *ip, double *w)
+void cdft(int n, int isgn, FFTFLT *a, int *ip, FFTFLT *w)
 {
-    void makewt(int nw, int *ip, double *w);
-    void cftfsub(int n, double *a, int *ip, int nw, double *w);
-    void cftbsub(int n, double *a, int *ip, int nw, double *w);
+    void makewt(int nw, int *ip, FFTFLT *w);
+    void cftfsub(int n, FFTFLT *a, int *ip, int nw, FFTFLT *w);
+    void cftbsub(int n, FFTFLT *a, int *ip, int nw, FFTFLT *w);
     int nw;
     
     nw = ip[0];
@@ -453,16 +470,16 @@ void cdft(int n, int isgn, double *a, int *ip, double *w)
 }
 
 
-void rdft(int n, int isgn, double *a, int *ip, double *w)
+void rdft(int n, int isgn, FFTFLT *a, int *ip, FFTFLT *w)
 {
-    void makewt(int nw, int *ip, double *w);
-    void makect(int nc, int *ip, double *c);
-    void cftfsub(int n, double *a, int *ip, int nw, double *w);
-    void cftbsub(int n, double *a, int *ip, int nw, double *w);
-    void rftfsub(int n, double *a, int nc, double *c);
-    void rftbsub(int n, double *a, int nc, double *c);
+    void makewt(int nw, int *ip, FFTFLT *w);
+    void makect(int nc, int *ip, FFTFLT *c);
+    void cftfsub(int n, FFTFLT *a, int *ip, int nw, FFTFLT *w);
+    void cftbsub(int n, FFTFLT *a, int *ip, int nw, FFTFLT *w);
+    void rftfsub(int n, FFTFLT *a, int nc, FFTFLT *c);
+    void rftbsub(int n, FFTFLT *a, int nc, FFTFLT *c);
     int nw, nc;
-    double xi;
+    FFTFLT xi;
     
     nw = ip[0];
     if (n > (nw << 2)) {
@@ -497,17 +514,17 @@ void rdft(int n, int isgn, double *a, int *ip, double *w)
 }
 
 
-void ddct(int n, int isgn, double *a, int *ip, double *w)
+void ddct(int n, int isgn, FFTFLT *a, int *ip, FFTFLT *w)
 {
-    void makewt(int nw, int *ip, double *w);
-    void makect(int nc, int *ip, double *c);
-    void cftfsub(int n, double *a, int *ip, int nw, double *w);
-    void cftbsub(int n, double *a, int *ip, int nw, double *w);
-    void rftfsub(int n, double *a, int nc, double *c);
-    void rftbsub(int n, double *a, int nc, double *c);
-    void dctsub(int n, double *a, int nc, double *c);
+    void makewt(int nw, int *ip, FFTFLT *w);
+    void makect(int nc, int *ip, FFTFLT *c);
+    void cftfsub(int n, FFTFLT *a, int *ip, int nw, FFTFLT *w);
+    void cftbsub(int n, FFTFLT *a, int *ip, int nw, FFTFLT *w);
+    void rftfsub(int n, FFTFLT *a, int nc, FFTFLT *c);
+    void rftbsub(int n, FFTFLT *a, int nc, FFTFLT *c);
+    void dctsub(int n, FFTFLT *a, int nc, FFTFLT *c);
     int j, nw, nc;
-    double xr;
+    FFTFLT xr;
     
     nw = ip[0];
     if (n > (nw << 2)) {
@@ -553,17 +570,17 @@ void ddct(int n, int isgn, double *a, int *ip, double *w)
 }
 
 
-void ddst(int n, int isgn, double *a, int *ip, double *w)
+void ddst(int n, int isgn, FFTFLT *a, int *ip, FFTFLT *w)
 {
-    void makewt(int nw, int *ip, double *w);
-    void makect(int nc, int *ip, double *c);
-    void cftfsub(int n, double *a, int *ip, int nw, double *w);
-    void cftbsub(int n, double *a, int *ip, int nw, double *w);
-    void rftfsub(int n, double *a, int nc, double *c);
-    void rftbsub(int n, double *a, int nc, double *c);
-    void dstsub(int n, double *a, int nc, double *c);
+    void makewt(int nw, int *ip, FFTFLT *w);
+    void makect(int nc, int *ip, FFTFLT *c);
+    void cftfsub(int n, FFTFLT *a, int *ip, int nw, FFTFLT *w);
+    void cftbsub(int n, FFTFLT *a, int *ip, int nw, FFTFLT *w);
+    void rftfsub(int n, FFTFLT *a, int nc, FFTFLT *c);
+    void rftbsub(int n, FFTFLT *a, int nc, FFTFLT *c);
+    void dstsub(int n, FFTFLT *a, int nc, FFTFLT *c);
     int j, nw, nc;
-    double xr;
+    FFTFLT xr;
     
     nw = ip[0];
     if (n > (nw << 2)) {
@@ -609,15 +626,15 @@ void ddst(int n, int isgn, double *a, int *ip, double *w)
 }
 
 
-void dfct(int n, double *a, double *t, int *ip, double *w)
+void dfct(int n, FFTFLT *a, FFTFLT *t, int *ip, FFTFLT *w)
 {
-    void makewt(int nw, int *ip, double *w);
-    void makect(int nc, int *ip, double *c);
-    void cftfsub(int n, double *a, int *ip, int nw, double *w);
-    void rftfsub(int n, double *a, int nc, double *c);
-    void dctsub(int n, double *a, int nc, double *c);
+    void makewt(int nw, int *ip, FFTFLT *w);
+    void makect(int nc, int *ip, FFTFLT *c);
+    void cftfsub(int n, FFTFLT *a, int *ip, int nw, FFTFLT *w);
+    void rftfsub(int n, FFTFLT *a, int nc, FFTFLT *c);
+    void dctsub(int n, FFTFLT *a, int nc, FFTFLT *c);
     int j, k, l, m, mh, nw, nc;
-    double xr, xi, yr, yi;
+    FFTFLT xr, xi, yr, yi;
     
     nw = ip[0];
     if (n > (nw << 3)) {
@@ -702,15 +719,15 @@ void dfct(int n, double *a, double *t, int *ip, double *w)
 }
 
 
-void dfst(int n, double *a, double *t, int *ip, double *w)
+void dfst(int n, FFTFLT *a, FFTFLT *t, int *ip, FFTFLT *w)
 {
-    void makewt(int nw, int *ip, double *w);
-    void makect(int nc, int *ip, double *c);
-    void cftfsub(int n, double *a, int *ip, int nw, double *w);
-    void rftfsub(int n, double *a, int nc, double *c);
-    void dstsub(int n, double *a, int nc, double *c);
+    void makewt(int nw, int *ip, FFTFLT *w);
+    void makect(int nc, int *ip, FFTFLT *c);
+    void cftfsub(int n, FFTFLT *a, int *ip, int nw, FFTFLT *w);
+    void rftfsub(int n, FFTFLT *a, int nc, FFTFLT *c);
+    void dstsub(int n, FFTFLT *a, int nc, FFTFLT *c);
     int j, k, l, m, mh, nw, nc;
-    double xr, xi, yr, yi;
+    FFTFLT xr, xi, yr, yi;
     
     nw = ip[0];
     if (n > (nw << 3)) {
@@ -791,11 +808,11 @@ void dfst(int n, double *a, double *t, int *ip, double *w)
 
 #include <math.h>
 
-void makewt(int nw, int *ip, double *w)
+void makewt(int nw, int *ip, FFTFLT *w)
 {
     void makeipt(int nw, int *ip);
     int j, nwh, nw0, nw1;
-    double delta, wn4r, wk1r, wk1i, wk3r, wk3i;
+    FFTFLT delta, wn4r, wk1r, wk1i, wk3r, wk3i;
     
     ip[0] = nw;
     ip[1] = 1;
@@ -872,10 +889,10 @@ void makeipt(int nw, int *ip)
 }
 
 
-void makect(int nc, int *ip, double *c)
+void makect(int nc, int *ip, FFTFLT *c)
 {
     int j, nch;
-    double delta;
+    FFTFLT delta;
     
     ip[1] = nc;
     if (nc > 1) {
@@ -948,21 +965,21 @@ void makect(int nc, int *ip, double *c)
 #endif /* USE_CDFT_WINTHREADS */
 
 
-void cftfsub(int n, double *a, int *ip, int nw, double *w)
+void cftfsub(int n, FFTFLT *a, int *ip, int nw, FFTFLT *w)
 {
-    void bitrv2(int n, int *ip, double *a);
-    void bitrv216(double *a);
-    void bitrv208(double *a);
-    void cftf1st(int n, double *a, double *w);
-    void cftrec4(int n, double *a, int nw, double *w);
-    void cftleaf(int n, int isplt, double *a, int nw, double *w);
-    void cftfx41(int n, double *a, int nw, double *w);
-    void cftf161(double *a, double *w);
-    void cftf081(double *a, double *w);
-    void cftf040(double *a);
-    void cftx020(double *a);
+    void bitrv2(int n, int *ip, FFTFLT *a);
+    void bitrv216(FFTFLT *a);
+    void bitrv208(FFTFLT *a);
+    void cftf1st(int n, FFTFLT *a, FFTFLT *w);
+    void cftrec4(int n, FFTFLT *a, int nw, FFTFLT *w);
+    void cftleaf(int n, int isplt, FFTFLT *a, int nw, FFTFLT *w);
+    void cftfx41(int n, FFTFLT *a, int nw, FFTFLT *w);
+    void cftf161(FFTFLT *a, FFTFLT *w);
+    void cftf081(FFTFLT *a, FFTFLT *w);
+    void cftf040(FFTFLT *a);
+    void cftx020(FFTFLT *a);
 #ifdef USE_CDFT_THREADS
-    void cftrec4_th(int n, double *a, int nw, double *w);
+    void cftrec4_th(int n, FFTFLT *a, int nw, FFTFLT *w);
 #endif /* USE_CDFT_THREADS */
     
     if (n > 8) {
@@ -996,21 +1013,21 @@ void cftfsub(int n, double *a, int *ip, int nw, double *w)
 }
 
 
-void cftbsub(int n, double *a, int *ip, int nw, double *w)
+void cftbsub(int n, FFTFLT *a, int *ip, int nw, FFTFLT *w)
 {
-    void bitrv2conj(int n, int *ip, double *a);
-    void bitrv216neg(double *a);
-    void bitrv208neg(double *a);
-    void cftb1st(int n, double *a, double *w);
-    void cftrec4(int n, double *a, int nw, double *w);
-    void cftleaf(int n, int isplt, double *a, int nw, double *w);
-    void cftfx41(int n, double *a, int nw, double *w);
-    void cftf161(double *a, double *w);
-    void cftf081(double *a, double *w);
-    void cftb040(double *a);
-    void cftx020(double *a);
+    void bitrv2conj(int n, int *ip, FFTFLT *a);
+    void bitrv216neg(FFTFLT *a);
+    void bitrv208neg(FFTFLT *a);
+    void cftb1st(int n, FFTFLT *a, FFTFLT *w);
+    void cftrec4(int n, FFTFLT *a, int nw, FFTFLT *w);
+    void cftleaf(int n, int isplt, FFTFLT *a, int nw, FFTFLT *w);
+    void cftfx41(int n, FFTFLT *a, int nw, FFTFLT *w);
+    void cftf161(FFTFLT *a, FFTFLT *w);
+    void cftf081(FFTFLT *a, FFTFLT *w);
+    void cftb040(FFTFLT *a);
+    void cftx020(FFTFLT *a);
 #ifdef USE_CDFT_THREADS
-    void cftrec4_th(int n, double *a, int nw, double *w);
+    void cftrec4_th(int n, FFTFLT *a, int nw, FFTFLT *w);
 #endif /* USE_CDFT_THREADS */
     
     if (n > 8) {
@@ -1044,10 +1061,10 @@ void cftbsub(int n, double *a, int *ip, int nw, double *w)
 }
 
 
-void bitrv2(int n, int *ip, double *a)
+void bitrv2(int n, int *ip, FFTFLT *a)
 {
     int j, j1, k, k1, l, m, nh, nm;
-    double xr, xi, yr, yi;
+    FFTFLT xr, xi, yr, yi;
     
     m = 1;
     for (l = n >> 2; l > 8; l >>= 2) {
@@ -1391,10 +1408,10 @@ void bitrv2(int n, int *ip, double *a)
 }
 
 
-void bitrv2conj(int n, int *ip, double *a)
+void bitrv2conj(int n, int *ip, FFTFLT *a)
 {
     int j, j1, k, k1, l, m, nh, nm;
-    double xr, xi, yr, yi;
+    FFTFLT xr, xi, yr, yi;
     
     m = 1;
     for (l = n >> 2; l > 8; l >>= 2) {
@@ -1746,9 +1763,9 @@ void bitrv2conj(int n, int *ip, double *a)
 }
 
 
-void bitrv216(double *a)
+void bitrv216(FFTFLT *a)
 {
-    double x1r, x1i, x2r, x2i, x3r, x3i, x4r, x4i, 
+    FFTFLT x1r, x1i, x2r, x2i, x3r, x3i, x4r, x4i, 
         x5r, x5i, x7r, x7i, x8r, x8i, x10r, x10i, 
         x11r, x11i, x12r, x12i, x13r, x13i, x14r, x14i;
     
@@ -1803,9 +1820,9 @@ void bitrv216(double *a)
 }
 
 
-void bitrv216neg(double *a)
+void bitrv216neg(FFTFLT *a)
 {
-    double x1r, x1i, x2r, x2i, x3r, x3i, x4r, x4i, 
+    FFTFLT x1r, x1i, x2r, x2i, x3r, x3i, x4r, x4i, 
         x5r, x5i, x6r, x6i, x7r, x7i, x8r, x8i, 
         x9r, x9i, x10r, x10i, x11r, x11i, x12r, x12i, 
         x13r, x13i, x14r, x14i, x15r, x15i;
@@ -1873,9 +1890,9 @@ void bitrv216neg(double *a)
 }
 
 
-void bitrv208(double *a)
+void bitrv208(FFTFLT *a)
 {
-    double x1r, x1i, x3r, x3i, x4r, x4i, x6r, x6i;
+    FFTFLT x1r, x1i, x3r, x3i, x4r, x4i, x6r, x6i;
     
     x1r = a[2];
     x1i = a[3];
@@ -1896,9 +1913,9 @@ void bitrv208(double *a)
 }
 
 
-void bitrv208neg(double *a)
+void bitrv208neg(FFTFLT *a)
 {
-    double x1r, x1i, x2r, x2i, x3r, x3i, x4r, x4i, 
+    FFTFLT x1r, x1i, x2r, x2i, x3r, x3i, x4r, x4i, 
         x5r, x5i, x6r, x6i, x7r, x7i;
     
     x1r = a[2];
@@ -1932,12 +1949,12 @@ void bitrv208neg(double *a)
 }
 
 
-void cftf1st(int n, double *a, double *w)
+void cftf1st(int n, FFTFLT *a, FFTFLT *w)
 {
     int j, j0, j1, j2, j3, k, m, mh;
-    double wn4r, csc1, csc3, wk1r, wk1i, wk3r, wk3i, 
+    FFTFLT wn4r, csc1, csc3, wk1r, wk1i, wk3r, wk3i, 
         wd1r, wd1i, wd3r, wd3i;
-    double x0r, x0i, x1r, x1i, x2r, x2i, x3r, x3i, 
+    FFTFLT x0r, x0i, x1r, x1i, x2r, x2i, x3r, x3i, 
         y0r, y0i, y1r, y1i, y2r, y2i, y3r, y3i;
     
     mh = n >> 3;
@@ -2138,12 +2155,12 @@ void cftf1st(int n, double *a, double *w)
 }
 
 
-void cftb1st(int n, double *a, double *w)
+void cftb1st(int n, FFTFLT *a, FFTFLT *w)
 {
     int j, j0, j1, j2, j3, k, m, mh;
-    double wn4r, csc1, csc3, wk1r, wk1i, wk3r, wk3i, 
+    FFTFLT wn4r, csc1, csc3, wk1r, wk1i, wk3r, wk3i, 
         wd1r, wd1i, wd3r, wd3i;
-    double x0r, x0i, x1r, x1i, x2r, x2i, x3r, x3i, 
+    FFTFLT x0r, x0i, x1r, x1i, x2r, x2i, x3r, x3i, 
         y0r, y0i, y1r, y1i, y2r, y2i, y3r, y3i;
     
     mh = n >> 3;
@@ -2348,14 +2365,14 @@ void cftb1st(int n, double *a, double *w)
 struct cdft_arg_st {
     int n0;
     int n;
-    double *a;
+    FFTFLT *a;
     int nw;
-    double *w;
+    FFTFLT *w;
 };
 typedef struct cdft_arg_st cdft_arg_t;
 
 
-void cftrec4_th(int n, double *a, int nw, double *w)
+void cftrec4_th(int n, FFTFLT *a, int nw, FFTFLT *w)
 {
     void *cftrec1_th(void *p);
     void *cftrec2_th(void *p);
@@ -2391,11 +2408,11 @@ void cftrec4_th(int n, double *a, int nw, double *w)
 
 void *cftrec1_th(void *p)
 {
-    int cfttree(int n, int j, int k, double *a, int nw, double *w);
-    void cftleaf(int n, int isplt, double *a, int nw, double *w);
-    void cftmdl1(int n, double *a, double *w);
+    int cfttree(int n, int j, int k, FFTFLT *a, int nw, FFTFLT *w);
+    void cftleaf(int n, int isplt, FFTFLT *a, int nw, FFTFLT *w);
+    void cftmdl1(int n, FFTFLT *a, FFTFLT *w);
     int isplt, j, k, m, n, n0, nw;
-    double *a, *w;
+    FFTFLT *a, *w;
     
     n0 = ((cdft_arg_t *) p)->n0;
     n = ((cdft_arg_t *) p)->n;
@@ -2420,11 +2437,11 @@ void *cftrec1_th(void *p)
 
 void *cftrec2_th(void *p)
 {
-    int cfttree(int n, int j, int k, double *a, int nw, double *w);
-    void cftleaf(int n, int isplt, double *a, int nw, double *w);
-    void cftmdl2(int n, double *a, double *w);
+    int cfttree(int n, int j, int k, FFTFLT *a, int nw, FFTFLT *w);
+    void cftleaf(int n, int isplt, FFTFLT *a, int nw, FFTFLT *w);
+    void cftmdl2(int n, FFTFLT *a, FFTFLT *w);
     int isplt, j, k, m, n, n0, nw;
-    double *a, *w;
+    FFTFLT *a, *w;
     
     n0 = ((cdft_arg_t *) p)->n0;
     n = ((cdft_arg_t *) p)->n;
@@ -2450,11 +2467,11 @@ void *cftrec2_th(void *p)
 #endif /* USE_CDFT_THREADS */
 
 
-void cftrec4(int n, double *a, int nw, double *w)
+void cftrec4(int n, FFTFLT *a, int nw, FFTFLT *w)
 {
-    int cfttree(int n, int j, int k, double *a, int nw, double *w);
-    void cftleaf(int n, int isplt, double *a, int nw, double *w);
-    void cftmdl1(int n, double *a, double *w);
+    int cfttree(int n, int j, int k, FFTFLT *a, int nw, FFTFLT *w);
+    void cftleaf(int n, int isplt, FFTFLT *a, int nw, FFTFLT *w);
+    void cftmdl1(int n, FFTFLT *a, FFTFLT *w);
     int isplt, j, k, m;
     
     m = n;
@@ -2472,10 +2489,10 @@ void cftrec4(int n, double *a, int nw, double *w)
 }
 
 
-int cfttree(int n, int j, int k, double *a, int nw, double *w)
+int cfttree(int n, int j, int k, FFTFLT *a, int nw, FFTFLT *w)
 {
-    void cftmdl1(int n, double *a, double *w);
-    void cftmdl2(int n, double *a, double *w);
+    void cftmdl1(int n, FFTFLT *a, FFTFLT *w);
+    void cftmdl2(int n, FFTFLT *a, FFTFLT *w);
     int i, isplt, m;
     
     if ((k & 3) != 0) {
@@ -2507,14 +2524,14 @@ int cfttree(int n, int j, int k, double *a, int nw, double *w)
 }
 
 
-void cftleaf(int n, int isplt, double *a, int nw, double *w)
+void cftleaf(int n, int isplt, FFTFLT *a, int nw, FFTFLT *w)
 {
-    void cftmdl1(int n, double *a, double *w);
-    void cftmdl2(int n, double *a, double *w);
-    void cftf161(double *a, double *w);
-    void cftf162(double *a, double *w);
-    void cftf081(double *a, double *w);
-    void cftf082(double *a, double *w);
+    void cftmdl1(int n, FFTFLT *a, FFTFLT *w);
+    void cftmdl2(int n, FFTFLT *a, FFTFLT *w);
+    void cftf161(FFTFLT *a, FFTFLT *w);
+    void cftf162(FFTFLT *a, FFTFLT *w);
+    void cftf081(FFTFLT *a, FFTFLT *w);
+    void cftf082(FFTFLT *a, FFTFLT *w);
     
     if (n == 512) {
         cftmdl1(128, a, &w[nw - 64]);
@@ -2572,11 +2589,11 @@ void cftleaf(int n, int isplt, double *a, int nw, double *w)
 }
 
 
-void cftmdl1(int n, double *a, double *w)
+void cftmdl1(int n, FFTFLT *a, FFTFLT *w)
 {
     int j, j0, j1, j2, j3, k, m, mh;
-    double wn4r, wk1r, wk1i, wk3r, wk3i;
-    double x0r, x0i, x1r, x1i, x2r, x2i, x3r, x3i;
+    FFTFLT wn4r, wk1r, wk1i, wk3r, wk3i;
+    FFTFLT x0r, x0i, x1r, x1i, x2r, x2i, x3r, x3i;
     
     mh = n >> 3;
     m = 2 * mh;
@@ -2682,11 +2699,11 @@ void cftmdl1(int n, double *a, double *w)
 }
 
 
-void cftmdl2(int n, double *a, double *w)
+void cftmdl2(int n, FFTFLT *a, FFTFLT *w)
 {
     int j, j0, j1, j2, j3, k, kr, m, mh;
-    double wn4r, wk1r, wk1i, wk3r, wk3i, wd1r, wd1i, wd3r, wd3i;
-    double x0r, x0i, x1r, x1i, x2r, x2i, x3r, x3i, y0r, y0i, y2r, y2i;
+    FFTFLT wn4r, wk1r, wk1i, wk3r, wk3i, wd1r, wd1i, wd3r, wd3i;
+    FFTFLT x0r, x0i, x1r, x1i, x2r, x2i, x3r, x3i, y0r, y0i, y2r, y2i;
     
     mh = n >> 3;
     m = 2 * mh;
@@ -2816,12 +2833,12 @@ void cftmdl2(int n, double *a, double *w)
 }
 
 
-void cftfx41(int n, double *a, int nw, double *w)
+void cftfx41(int n, FFTFLT *a, int nw, FFTFLT *w)
 {
-    void cftf161(double *a, double *w);
-    void cftf162(double *a, double *w);
-    void cftf081(double *a, double *w);
-    void cftf082(double *a, double *w);
+    void cftf161(FFTFLT *a, FFTFLT *w);
+    void cftf162(FFTFLT *a, FFTFLT *w);
+    void cftf081(FFTFLT *a, FFTFLT *w);
+    void cftf082(FFTFLT *a, FFTFLT *w);
     
     if (n == 128) {
         cftf161(a, &w[nw - 8]);
@@ -2837,9 +2854,9 @@ void cftfx41(int n, double *a, int nw, double *w)
 }
 
 
-void cftf161(double *a, double *w)
+void cftf161(FFTFLT *a, FFTFLT *w)
 {
-    double wn4r, wk1r, wk1i, 
+    FFTFLT wn4r, wk1r, wk1i, 
         x0r, x0i, x1r, x1i, x2r, x2i, x3r, x3i, 
         y0r, y0i, y1r, y1i, y2r, y2i, y3r, y3i, 
         y4r, y4i, y5r, y5i, y6r, y6i, y7r, y7i, 
@@ -2996,9 +3013,9 @@ void cftf161(double *a, double *w)
 }
 
 
-void cftf162(double *a, double *w)
+void cftf162(FFTFLT *a, FFTFLT *w)
 {
-    double wn4r, wk1r, wk1i, wk2r, wk2i, wk3r, wk3i, 
+    FFTFLT wn4r, wk1r, wk1i, wk2r, wk2i, wk3r, wk3i, 
         x0r, x0i, x1r, x1i, x2r, x2i, 
         y0r, y0i, y1r, y1i, y2r, y2i, y3r, y3i, 
         y4r, y4i, y5r, y5i, y6r, y6i, y7r, y7i, 
@@ -3179,9 +3196,9 @@ void cftf162(double *a, double *w)
 }
 
 
-void cftf081(double *a, double *w)
+void cftf081(FFTFLT *a, FFTFLT *w)
 {
-    double wn4r, x0r, x0i, x1r, x1i, x2r, x2i, x3r, x3i, 
+    FFTFLT wn4r, x0r, x0i, x1r, x1i, x2r, x2i, x3r, x3i, 
         y0r, y0i, y1r, y1i, y2r, y2i, y3r, y3i, 
         y4r, y4i, y5r, y5i, y6r, y6i, y7r, y7i;
     
@@ -3241,9 +3258,9 @@ void cftf081(double *a, double *w)
 }
 
 
-void cftf082(double *a, double *w)
+void cftf082(FFTFLT *a, FFTFLT *w)
 {
-    double wn4r, wk1r, wk1i, x0r, x0i, x1r, x1i, 
+    FFTFLT wn4r, wk1r, wk1i, x0r, x0i, x1r, x1i, 
         y0r, y0i, y1r, y1i, y2r, y2i, y3r, y3i, 
         y4r, y4i, y5r, y5i, y6r, y6i, y7r, y7i;
     
@@ -3313,9 +3330,9 @@ void cftf082(double *a, double *w)
 }
 
 
-void cftf040(double *a)
+void cftf040(FFTFLT *a)
 {
-    double x0r, x0i, x1r, x1i, x2r, x2i, x3r, x3i;
+    FFTFLT x0r, x0i, x1r, x1i, x2r, x2i, x3r, x3i;
     
     x0r = a[0] + a[4];
     x0i = a[1] + a[5];
@@ -3336,9 +3353,9 @@ void cftf040(double *a)
 }
 
 
-void cftb040(double *a)
+void cftb040(FFTFLT *a)
 {
-    double x0r, x0i, x1r, x1i, x2r, x2i, x3r, x3i;
+    FFTFLT x0r, x0i, x1r, x1i, x2r, x2i, x3r, x3i;
     
     x0r = a[0] + a[4];
     x0i = a[1] + a[5];
@@ -3359,9 +3376,9 @@ void cftb040(double *a)
 }
 
 
-void cftx020(double *a)
+void cftx020(FFTFLT *a)
 {
-    double x0r, x0i;
+    FFTFLT x0r, x0i;
     
     x0r = a[0] - a[2];
     x0i = a[1] - a[3];
@@ -3372,10 +3389,10 @@ void cftx020(double *a)
 }
 
 
-void rftfsub(int n, double *a, int nc, double *c)
+void rftfsub(int n, FFTFLT *a, int nc, FFTFLT *c)
 {
     int j, k, kk, ks, m;
-    double wkr, wki, xr, xi, yr, yi;
+    FFTFLT wkr, wki, xr, xi, yr, yi;
     
     m = n >> 1;
     ks = 2 * nc / m;
@@ -3397,10 +3414,10 @@ void rftfsub(int n, double *a, int nc, double *c)
 }
 
 
-void rftbsub(int n, double *a, int nc, double *c)
+void rftbsub(int n, FFTFLT *a, int nc, FFTFLT *c)
 {
     int j, k, kk, ks, m;
-    double wkr, wki, xr, xi, yr, yi;
+    FFTFLT wkr, wki, xr, xi, yr, yi;
     
     m = n >> 1;
     ks = 2 * nc / m;
@@ -3422,10 +3439,10 @@ void rftbsub(int n, double *a, int nc, double *c)
 }
 
 
-void dctsub(int n, double *a, int nc, double *c)
+void dctsub(int n, FFTFLT *a, int nc, FFTFLT *c)
 {
     int j, k, kk, ks, m;
-    double wkr, wki, xr;
+    FFTFLT wkr, wki, xr;
     
     m = n >> 1;
     ks = nc / n;
@@ -3443,10 +3460,10 @@ void dctsub(int n, double *a, int nc, double *c)
 }
 
 
-void dstsub(int n, double *a, int nc, double *c)
+void dstsub(int n, FFTFLT *a, int nc, FFTFLT *c)
 {
     int j, k, kk, ks, m;
-    double wkr, wki, xr;
+    FFTFLT wkr, wki, xr;
     
     m = n >> 1;
     ks = nc / n;
