@@ -132,7 +132,8 @@ void sighip_setup(void)
     sighip_class = class_new(gensym("hip~"), (t_newmethod)sighip_new, 0,
         sizeof(t_sighip), 0, A_DEFFLOAT, 0);
     CLASS_MAINSIGNALIN(sighip_class, t_sighip, x_f);
-    class_addmethod(sighip_class, (t_method)sighip_dsp, gensym("dsp"), 0);
+    class_addmethod(sighip_class, (t_method)sighip_dsp,
+        gensym("dsp"), A_CANT, 0);
     class_addmethod(sighip_class, (t_method)sighip_ft1,
         gensym("ft1"), A_FLOAT, 0);
     class_addmethod(sighip_class, (t_method)sighip_clear, gensym("clear"), 0);
@@ -222,7 +223,8 @@ void siglop_setup(void)
     siglop_class = class_new(gensym("lop~"), (t_newmethod)siglop_new, 0,
         sizeof(t_siglop), 0, A_DEFFLOAT, 0);
     CLASS_MAINSIGNALIN(siglop_class, t_siglop, x_f);
-    class_addmethod(siglop_class, (t_method)siglop_dsp, gensym("dsp"), 0);
+    class_addmethod(siglop_class, (t_method)siglop_dsp,
+        gensym("dsp"), A_CANT, 0);
     class_addmethod(siglop_class, (t_method)siglop_ft1,
         gensym("ft1"), A_FLOAT, 0);
     class_addmethod(siglop_class, (t_method)siglop_clear, gensym("clear"), 0);
@@ -356,7 +358,8 @@ void sigbp_setup(void)
     sigbp_class = class_new(gensym("bp~"), (t_newmethod)sigbp_new, 0,
         sizeof(t_sigbp), 0, A_DEFFLOAT, A_DEFFLOAT, 0);
     CLASS_MAINSIGNALIN(sigbp_class, t_sigbp, x_f);
-    class_addmethod(sigbp_class, (t_method)sigbp_dsp, gensym("dsp"), 0);
+    class_addmethod(sigbp_class, (t_method)sigbp_dsp,
+        gensym("dsp"), A_CANT, 0);
     class_addmethod(sigbp_class, (t_method)sigbp_ft1,
         gensym("ft1"), A_FLOAT, 0);
     class_addmethod(sigbp_class, (t_method)sigbp_ft2,
@@ -482,7 +485,8 @@ void sigbiquad_setup(void)
     sigbiquad_class = class_new(gensym("biquad~"), (t_newmethod)sigbiquad_new,
         0, sizeof(t_sigbiquad), 0, A_GIMME, 0);
     CLASS_MAINSIGNALIN(sigbiquad_class, t_sigbiquad, x_f);
-    class_addmethod(sigbiquad_class, (t_method)sigbiquad_dsp, gensym("dsp"), 0);
+    class_addmethod(sigbiquad_class, (t_method)sigbiquad_dsp,
+        gensym("dsp"), A_CANT, 0);
     class_addlist(sigbiquad_class, sigbiquad_list);
     class_addmethod(sigbiquad_class, (t_method)sigbiquad_set, gensym("set"),
         A_GIMME, 0);
@@ -564,7 +568,7 @@ void sigsamphold_setup(void)
     class_addmethod(sigsamphold_class, (t_method)sigsamphold_reset,
         gensym("reset"), A_GIMME, 0);
     class_addmethod(sigsamphold_class, (t_method)sigsamphold_dsp,
-        gensym("dsp"), 0);
+        gensym("dsp"), A_CANT, 0);
 }
 
 /* ---------------- rpole~ - real one-pole filter (raw) ----------------- */
@@ -637,7 +641,7 @@ void sigrpole_setup(void)
     class_addmethod(sigrpole_class, (t_method)sigrpole_clear,
         gensym("clear"), 0);
     class_addmethod(sigrpole_class, (t_method)sigrpole_dsp,
-        gensym("dsp"), 0);
+        gensym("dsp"), A_CANT, 0);
 }
 
 /* ---------------- rzero~ - real one-zero filter (raw) ----------------- */
@@ -709,7 +713,7 @@ void sigrzero_setup(void)
     class_addmethod(sigrzero_class, (t_method)sigrzero_clear,
         gensym("clear"), 0);
     class_addmethod(sigrzero_class, (t_method)sigrzero_dsp,
-        gensym("dsp"), 0);
+        gensym("dsp"), A_CANT, 0);
 }
 
 /* ---------- rzero_rev~ - real, reverse one-zero filter (raw) ------------ */
@@ -782,7 +786,7 @@ void sigrzero_rev_setup(void)
     class_addmethod(sigrzero_rev_class, (t_method)sigrzero_rev_clear,
         gensym("clear"), 0);
     class_addmethod(sigrzero_rev_class, (t_method)sigrzero_rev_dsp,
-        gensym("dsp"), 0);
+        gensym("dsp"), A_CANT, 0);
 }
 
 /* -------------- cpole~ - complex one-pole filter (raw) --------------- */
@@ -875,10 +879,10 @@ void sigcpole_setup(void)
     class_addmethod(sigcpole_class, (t_method)sigcpole_clear,
         gensym("clear"), 0);
     class_addmethod(sigcpole_class, (t_method)sigcpole_dsp,
-        gensym("dsp"), 0);
+        gensym("dsp"), A_CANT, 0);
 }
 
-/* -------------- czero~ - complex one-pole filter (raw) --------------- */
+/* -------------- czero~ - complex one-zero filter (raw) --------------- */
 
 typedef struct sigczero
 {
@@ -965,10 +969,10 @@ void sigczero_setup(void)
     class_addmethod(sigczero_class, (t_method)sigczero_clear,
         gensym("clear"), 0);
     class_addmethod(sigczero_class, (t_method)sigczero_dsp,
-        gensym("dsp"), 0);
+        gensym("dsp"), A_CANT, 0);
 }
 
-/* -------------- czero_rev~ - complex one-pole filter (raw) --------------- */
+/* ------ czero_rev~ - complex one-zero filter (raw, reverse form) ----- */
 
 typedef struct sigczero_rev
 {
@@ -1057,7 +1061,7 @@ void sigczero_rev_setup(void)
     class_addmethod(sigczero_rev_class, (t_method)sigczero_rev_clear,
         gensym("clear"), 0);
     class_addmethod(sigczero_rev_class, (t_method)sigczero_rev_dsp,
-        gensym("dsp"), 0);
+        gensym("dsp"), A_CANT, 0);
 }
 
 /* ------------------------ setup routine ------------------------- */
