@@ -241,7 +241,7 @@ static void hradio_save(t_gobj *z, t_binbuf *b)
     t_symbol *srl[3];
 
     iemgui_save(&x->x_gui, srl, bflcol);
-    binbuf_addv(b, "ssiisiiiisssiiiiiiii", gensym("#X"),gensym("obj"),
+    binbuf_addv(b, "ssiisiiiisssiiiiiiif", gensym("#X"),gensym("obj"),
                 (int)x->x_gui.x_obj.te_xpix, (int)x->x_gui.x_obj.te_ypix,
                 (pd_class(&x->x_gui.x_obj.ob_pd) == hradio_old_class ?
                     gensym("hdl") : gensym("hradio")),
@@ -250,7 +250,7 @@ static void hradio_save(t_gobj *z, t_binbuf *b)
                 srl[0], srl[1], srl[2],
                 x->x_gui.x_ldx, x->x_gui.x_ldy,
                 iem_fstyletoint(&x->x_gui.x_fsf), x->x_gui.x_fontsize,
-                bflcol[0], bflcol[1], bflcol[2], x->x_on);
+                bflcol[0], bflcol[1], bflcol[2], x->x_fval);
     binbuf_addv(b, ";");
 }
 
@@ -321,6 +321,7 @@ static void hradio_set(t_hradio *x, t_floatarg f)
     int i=(int)f;
     int old=x->x_on_old;
 
+    x->x_fval = f;
     if(i < 0)
         i = 0;
     if(i >= x->x_number)
@@ -362,9 +363,10 @@ static void hradio_bang(t_hradio *x)
     }
     else
     {
-        outlet_float(x->x_gui.x_obj.ob_outlet, x->x_on);
+        float outval = (pd_compatibilitylevel < 46 ? x->x_on : x->x_fval);
+        outlet_float(x->x_gui.x_obj.ob_outlet, outval);
         if(x->x_gui.x_fsf.x_snd_able && x->x_gui.x_snd->s_thing)
-            pd_float(x->x_gui.x_snd->s_thing, x->x_on);
+            pd_float(x->x_gui.x_snd->s_thing, outval);
     }
 }
 
@@ -372,6 +374,7 @@ static void hradio_fout(t_hradio *x, t_floatarg f)
 {
     int i=(int)f;
 
+    x->x_fval = f;
     if(i < 0)
         i = 0;
     if(i >= x->x_number)
@@ -400,19 +403,20 @@ static void hradio_fout(t_hradio *x, t_floatarg f)
     }
     else
     {
+        float outval = (pd_compatibilitylevel < 46 ? i : x->x_fval);
         x->x_on_old = x->x_on;
         x->x_on = i;
         (*x->x_gui.x_draw)(x, x->x_gui.x_glist, IEM_GUI_DRAW_MODE_UPDATE);
-        outlet_float(x->x_gui.x_obj.ob_outlet, x->x_on);
+        outlet_float(x->x_gui.x_obj.ob_outlet, outval);
         if(x->x_gui.x_fsf.x_snd_able && x->x_gui.x_snd->s_thing)
-            pd_float(x->x_gui.x_snd->s_thing, x->x_on);
+            pd_float(x->x_gui.x_snd->s_thing, outval);
     }
 }
 
 static void hradio_float(t_hradio *x, t_floatarg f)
 {
     int i=(int)f;
-
+    x->x_fval = f;
     if(i < 0)
         i = 0;
     if(i >= x->x_number)
@@ -448,14 +452,15 @@ static void hradio_float(t_hradio *x, t_floatarg f)
     }
     else
     {
+        float outval = (pd_compatibilitylevel < 46 ? i : x->x_fval);
         x->x_on_old = x->x_on;
         x->x_on = i;
         (*x->x_gui.x_draw)(x, x->x_gui.x_glist, IEM_GUI_DRAW_MODE_UPDATE);
         if (x->x_gui.x_fsf.x_put_in2out)
         {
-            outlet_float(x->x_gui.x_obj.ob_outlet, x->x_on);
+            outlet_float(x->x_gui.x_obj.ob_outlet, outval);
             if(x->x_gui.x_fsf.x_snd_able && x->x_gui.x_snd->s_thing)
-                pd_float(x->x_gui.x_snd->s_thing, x->x_on);
+                pd_float(x->x_gui.x_snd->s_thing, outval);
         }
     }
 }
@@ -545,11 +550,12 @@ static void *hradio_donew(t_symbol *s, int argc, t_atom *argv, int old)
 {
     t_hradio *x = (t_hradio *)pd_new(old? hradio_old_class : hradio_class);
     int bflcol[]={-262144, -1, -1};
-    int a=IEM_GUI_DEFAULTSIZE, on=0, f=0;
+    int a=IEM_GUI_DEFAULTSIZE, on = 0, f=0;
     int ldx=0, ldy=-8, chg=1, num=8;
     int fs=10;
     int ftbreak=IEM_BNG_DEFAULTBREAKFLASHTIME, fthold=IEM_BNG_DEFAULTHOLDFLASHTIME;
     char str[144];
+    float fval = 0;
 
     iem_inttosymargs(&x->x_gui.x_isa, 0);
     iem_inttofstyle(&x->x_gui.x_fsf, 0);
@@ -575,7 +581,7 @@ static void *hradio_donew(t_symbol *s, int argc, t_atom *argv, int old)
         bflcol[0] = (int)atom_getintarg(11, argc, argv);
         bflcol[1] = (int)atom_getintarg(12, argc, argv);
         bflcol[2] = (int)atom_getintarg(13, argc, argv);
-        on = (int)atom_getintarg(14, argc, argv);
+        fval = atom_getfloatarg(14, argc, argv);
     }
     else iemgui_new_getnames(&x->x_gui, 4, 0);
     x->x_gui.x_draw = (t_iemfunptr)hradio_draw;
@@ -595,6 +601,8 @@ static void *hradio_donew(t_symbol *s, int argc, t_atom *argv, int old)
     if(num > IEM_RADIO_MAX)
         num = IEM_RADIO_MAX;
     x->x_number = num;
+    x->x_fval = fval;
+    on = fval;
     if(on < 0)
         on = 0;
     if(on >= x->x_number)
