@@ -84,6 +84,8 @@ static void vinlet_anything(t_vinlet *x, t_symbol *s, int argc, t_atom *argv)
 static void vinlet_free(t_vinlet *x)
 {
     canvas_rminlet(x->x_canvas, x->x_inlet);
+    if (x->x_buf)
+        t_freebytes(x->x_buf, x->x_bufsize * sizeof(*x->x_buf));
     resample_free(&x->x_updown);
 }
 
@@ -287,7 +289,8 @@ static void vinlet_setup(void)
     class_addsymbol(vinlet_class, vinlet_symbol);
     class_addlist(vinlet_class, vinlet_list);
     class_addanything(vinlet_class, vinlet_anything);
-    class_addmethod(vinlet_class, (t_method)vinlet_dsp, gensym("dsp"), 0);
+    class_addmethod(vinlet_class, (t_method)vinlet_dsp, 
+        gensym("dsp"), A_CANT, 0);
     class_sethelpsymbol(vinlet_class, gensym("pd"));
 }
 
@@ -360,6 +363,8 @@ static void voutlet_anything(t_voutlet *x, t_symbol *s, int argc, t_atom *argv)
 static void voutlet_free(t_voutlet *x)
 {
     canvas_rmoutlet(x->x_canvas, x->x_parentoutlet);
+    if (x->x_buf)
+        t_freebytes(x->x_buf, x->x_bufsize * sizeof(*x->x_buf));
     resample_free(&x->x_updown);
 }
 
@@ -602,7 +607,8 @@ static void voutlet_setup(void)
     class_addsymbol(voutlet_class, voutlet_symbol);
     class_addlist(voutlet_class, voutlet_list);
     class_addanything(voutlet_class, voutlet_anything);
-    class_addmethod(voutlet_class, (t_method)voutlet_dsp, gensym("dsp"), 0);
+    class_addmethod(voutlet_class, (t_method)voutlet_dsp, 
+        gensym("dsp"), A_CANT, 0);
     class_sethelpsymbol(voutlet_class, gensym("pd"));
 }
 
