@@ -33,9 +33,15 @@ void glob_path_dialog(t_pd *dummy, t_symbol *s, int argc, t_atom *argv);
 void glob_start_startup_dialog(t_pd *dummy, t_floatarg flongform);
 void glob_startup_dialog(t_pd *dummy, t_symbol *s, int argc, t_atom *argv);
 void glob_ping(t_pd *dummy);
+void glob_plugindispatch(t_pd *dummy, t_symbol *s, int argc, t_atom *argv);
 void glob_watchdog(t_pd *dummy);
 void glob_savepreferences(t_pd *dummy);
 
+static void glob_helpintro(t_pd *dummy)
+{
+    open_via_helppath("intro.pd", "");
+}
+
 static void glob_compatibility(t_pd *dummy, t_floatarg level)
 {
     int dspwas = canvas_suspend_dsp();
@@ -92,6 +98,22 @@ void max_default(t_pd *x, t_symbol *s, int argc, t_atom *argv)
     endpost();
 }
 
+void glob_plugindispatch(t_pd *dummy, t_symbol *s, int argc, t_atom *argv)
+{
+    int i;
+    char str[80];
+    sys_vgui("pdtk_plugin_dispatch ");
+    for (i = 0; i < argc; i++)
+    {
+        atom_string(argv+i, str, 80);
+        sys_vgui("%s", str);
+        if (i < argc-1) {
+            sys_vgui(" ");
+        }
+    }
+    sys_vgui("\n");
+}
+
 void glob_init(void)
 {
     maxclass = class_new(gensym("max"), 0, 0, sizeof(t_pd),
@@ -150,6 +172,10 @@ void glob_init(void)
         gensym("perf"), A_FLOAT, 0);
     class_addmethod(glob_pdobject, (t_method)glob_compatibility,
         gensym("compatibility"), A_FLOAT, 0);
+    class_addmethod(glob_pdobject, (t_method)glob_plugindispatch,
+        gensym("plugin-dispatch"), A_GIMME, 0);
+    class_addmethod(glob_pdobject, (t_method)glob_helpintro,
+        gensym("help-intro"), A_GIMME, 0);
 #if defined(__linux__) || defined(__FreeBSD_kernel__)
     class_addmethod(glob_pdobject, (t_method)glob_watchdog,
         gensym("watchdog"), 0);
