@@ -169,7 +169,7 @@ static int alsaio_setup(t_alsa_dev *dev, int out, int *channels, int *rate,
 
         /* set the number of channels */
     tmp_uint = *channels;
-    err = snd_pcm_hw_params_set_channels_min(dev->a_handle,
+    err = snd_pcm_hw_params_set_channels_near(dev->a_handle,
         hw_params, &tmp_uint);
     check_error(err, out, "snd_pcm_hw_params_set_channels");
     if (tmp_uint != (unsigned)*channels)
@@ -925,9 +925,6 @@ void alsa_getdevs(char *indevlist, int *nindevs,
         const char *desc;
         if (2 * ndev + 2  > maxndev)
             break;
-            /* apparently, "cardno" is just a counter; but check that here */
-        if (ndev != cardno)
-            fprintf(stderr, "oops: ALSA cards not reported in order?\n");
         sprintf(devname, "hw:%d", cardno );
         /* fprintf(stderr, "\ntry %s...\n", devname); */
         if (snd_ctl_open(&ctl, devname, 0) >= 0)
