@@ -252,9 +252,9 @@ void sys_setextrapath(const char *p)
 #endif
 
 #ifdef _WIN32
-    sys_expandpath("%ProgramFiles%/Common Files/Pd", pathbuf, MAXPDSTRING);
+    sys_expandpath("%AppData%/Pd", pathbuf, MAXPDSTRING);
     sys_staticpath = namelist_append(0, pathbuf, 0);
-    sys_expandpath("%UserProfile%/Application Data/Pd", pathbuf, MAXPDSTRING);
+    sys_expandpath("%CommonProgramFiles%/Pd", pathbuf, MAXPDSTRING);
     sys_staticpath = namelist_append(sys_staticpath, pathbuf, 0);
 #endif
     /* add built-in "extra" path last so its checked last */
@@ -413,9 +413,9 @@ int sys_open(const char *path, int oflag, ...)
     /* For the create mode, Win32 does not have the same possibilities,
      * so we ignore the argument and just hard-code read/write. */
     if (oflag & O_CREAT)
-        fd = _wopen(ucs2path, oflag, _S_IREAD | _S_IWRITE);
+        fd = _wopen(ucs2path, oflag | O_BINARY, _S_IREAD | _S_IWRITE);
     else
-        fd = _wopen(ucs2path, oflag);
+        fd = _wopen(ucs2path, oflag | O_BINARY);
     return fd;
 }
 
