@@ -782,12 +782,7 @@ static void pack_symbol(t_pack *x, t_symbol *s)
 
 static void pack_list(t_pack *x, t_symbol *s, int ac, t_atom *av)
 {
-        /* this is a hasty bugfix for 0.45 - in 0.46 I'll try to fix this in
-        obj_list() instead. */
-    if(!ac)
-      pack_bang(x);
-    else
-      obj_list(&x->x_obj, 0, ac, av);
+    obj_list(&x->x_obj, 0, ac, av);
 }
 
 static void pack_anything(t_pack *x, t_symbol *s, int ac, t_atom *av)
