@@ -5,6 +5,7 @@
 /* MIDI. */
 
 #include "m_pd.h"
+#include "m_imp.h"
 void outmidi_noteon(int portno, int channel, int pitch, int velo);
 void outmidi_controlchange(int portno, int channel, int ctlno, int value);
 void outmidi_programchange(int portno, int channel, int value);
@@ -17,8 +18,6 @@ void outmidi_byte(int portno, int value);
 
 /* ----------------------- midiin and sysexin ------------------------- */
 
-static t_symbol *midiin_sym, *sysexin_sym;
-
 static t_class *midiin_class, *sysexin_class;
 
 typedef struct _midiin
@@ -33,10 +32,7 @@ static void *midiin_new( void)
     t_midiin *x = (t_midiin *)pd_new(midiin_class);
     x->x_outlet1 = outlet_new(&x->x_obj, &s_float);
     x->x_outlet2 = outlet_new(&x->x_obj, &s_float);
-    pd_bind(&x->x_obj.ob_pd, midiin_sym);
-#ifdef WIN32
-    pd_error(x, "midiin: windows: not supported");
-#endif
+    pd_bind(&x->x_obj.ob_pd, pd_this->pd_midiin_sym);
     return (x);
 }
 
@@ -48,7 +44,7 @@ static void midiin_list(t_midiin *x, t_symbol *s, int ac, t_atom *av)
 
 static void midiin_free(t_midiin *x)
 {
-    pd_unbind(&x->x_obj.ob_pd, midiin_sym);
+    pd_unbind(&x->x_obj.ob_pd, pd_this->pd_midiin_sym);
 }
 
 static void *sysexin_new( void)
@@ -56,16 +52,13 @@ static void *sysexin_new( void)
     t_midiin *x = (t_midiin *)pd_new(sysexin_class);
     x->x_outlet1 = outlet_new(&x->x_obj, &s_float);
     x->x_outlet2 = outlet_new(&x->x_obj, &s_float);
-    pd_bind(&x->x_obj.ob_pd, sysexin_sym);
-#ifdef WIN32
-    pd_error(x, "sysexin: windows: not supported");
-#endif
+    pd_bind(&x->x_obj.ob_pd, pd_this->pd_sysexin_sym);
     return (x);
 }
 
 static void sysexin_free(t_midiin *x)
 {
-    pd_unbind(&x->x_obj.ob_pd, sysexin_sym);
+    pd_unbind(&x->x_obj.ob_pd, pd_this->pd_sysexin_sym);
 }
 
 static void midiin_setup(void)
@@ -75,42 +68,38 @@ static void midiin_setup(void)
             CLASS_NOINLET, A_DEFFLOAT, 0);
     class_addlist(midiin_class, midiin_list);
     class_sethelpsymbol(midiin_class, gensym("midi"));
-    midiin_sym = gensym("#midiin");
 
     sysexin_class = class_new(gensym("sysexin"), (t_newmethod)sysexin_new,
         (t_method)sysexin_free, sizeof(t_midiin),
             CLASS_NOINLET, A_DEFFLOAT, 0);
     class_addlist(sysexin_class, midiin_list);
     class_sethelpsymbol(sysexin_class, gensym("midi"));
-    sysexin_sym = gensym("#sysexin");
 }
 
 void inmidi_byte(int portno, int byte)
 {
     t_atom at[2];
-    if (midiin_sym->s_thing)
+    if (pd_this->pd_midiin_sym->s_thing)
     {
         SETFLOAT(at, byte);
         SETFLOAT(at+1, portno);
-        pd_list(midiin_sym->s_thing, 0, 2, at);
+        pd_list(pd_this->pd_midiin_sym->s_thing, 0, 2, at);
     }
 }
 
 void inmidi_sysex(int portno, int byte)
 {
     t_atom at[2];
-    if (sysexin_sym->s_thing)
+    if (pd_this->pd_sysexin_sym->s_thing)
     {
         SETFLOAT(at, byte);
         SETFLOAT(at+1, portno);
-        pd_list(sysexin_sym->s_thing, 0, 2, at);
+        pd_list(pd_this->pd_sysexin_sym->s_thing, 0, 2, at);
     }
 }
 
 /* ----------------------- notein ------------------------- */
 
-static t_symbol *notein_sym;
-
 static t_class *notein_class;
 
 typedef struct _notein
@@ -129,7 +118,7 @@ static void *notein_new(t_floatarg f)
     x->x_outlet1 = outlet_new(&x->x_obj, &s_float);
     x->x_outlet2 = outlet_new(&x->x_obj, &s_float);
     if (f == 0) x->x_outlet3 = outlet_new(&x->x_obj, &s_float);
-    pd_bind(&x->x_obj.ob_pd, notein_sym);
+    pd_bind(&x->x_obj.ob_pd, pd_this->pd_notein_sym);
     return (x);
 }
 
@@ -154,7 +143,7 @@ static void notein_list(t_notein *x, t_symbol *s, int argc, t_atom *argv)
 
 static void notein_free(t_notein *x)
 {
-    pd_unbind(&x->x_obj.ob_pd, notein_sym);
+    pd_unbind(&x->x_obj.ob_pd, pd_this->pd_notein_sym);
 }
 
 static void notein_setup(void)
@@ -163,25 +152,22 @@ static void notein_setup(void)
         (t_method)notein_free, sizeof(t_notein), CLASS_NOINLET, A_DEFFLOAT, 0);
     class_addlist(notein_class, notein_list);
     class_sethelpsymbol(notein_class, gensym("midi"));
-    notein_sym = gensym("#notein");
 }
 
 void inmidi_noteon(int portno, int channel, int pitch, int velo)
 {
-    if (notein_sym->s_thing)
+    if (pd_this->pd_notein_sym->s_thing)
     {
         t_atom at[3];
         SETFLOAT(at, pitch);
         SETFLOAT(at+1, velo);
         SETFLOAT(at+2, (channel + (portno << 4) + 1));
-        pd_list(notein_sym->s_thing, &s_list, 3, at);
+        pd_list(pd_this->pd_notein_sym->s_thing, &s_list, 3, at);
     }
 }
 
 /* ----------------------- ctlin ------------------------- */
 
-static t_symbol *ctlin_sym;
-
 static t_class *ctlin_class;
 
 typedef struct _ctlin
@@ -209,7 +195,7 @@ static void *ctlin_new(t_symbol *s, int argc, t_atom *argv)
         if (x->x_ctlno < 0) x->x_outlet2 = outlet_new(&x->x_obj, &s_float);
         x->x_outlet3 = outlet_new(&x->x_obj, &s_float);
     }
-    pd_bind(&x->x_obj.ob_pd, ctlin_sym);
+    pd_bind(&x->x_obj.ob_pd, pd_this->pd_ctlin_sym);
     return (x);
 }
 
@@ -227,7 +213,7 @@ static void ctlin_list(t_ctlin *x, t_symbol *s, int argc, t_atom *argv)
 
 static void ctlin_free(t_ctlin *x)
 {
-    pd_unbind(&x->x_obj.ob_pd, ctlin_sym);
+    pd_unbind(&x->x_obj.ob_pd, pd_this->pd_ctlin_sym);
 }
 
 static void ctlin_setup(void)
@@ -237,25 +223,22 @@ static void ctlin_setup(void)
             CLASS_NOINLET, A_GIMME, 0);
     class_addlist(ctlin_class, ctlin_list);
     class_sethelpsymbol(ctlin_class, gensym("midi"));
-    ctlin_sym = gensym("#ctlin");
 }
 
 void inmidi_controlchange(int portno, int channel, int ctlnumber, int value)
 {
-    if (ctlin_sym->s_thing)
+    if (pd_this->pd_ctlin_sym->s_thing)
     {
         t_atom at[3];
         SETFLOAT(at, ctlnumber);
         SETFLOAT(at+1, value);
         SETFLOAT(at+2, (channel + (portno << 4) + 1));
-        pd_list(ctlin_sym->s_thing, &s_list, 3, at);
+        pd_list(pd_this->pd_ctlin_sym->s_thing, &s_list, 3, at);
     }
 }
 
 /* ----------------------- pgmin ------------------------- */
 
-static t_symbol *pgmin_sym;
-
 static t_class *pgmin_class;
 
 typedef struct _pgmin
@@ -272,7 +255,7 @@ static void *pgmin_new(t_floatarg f)
     x->x_channel = f;
     x->x_outlet1 = outlet_new(&x->x_obj, &s_float);
     if (f == 0) x->x_outlet2 = outlet_new(&x->x_obj, &s_float);
-    pd_bind(&x->x_obj.ob_pd, pgmin_sym);
+    pd_bind(&x->x_obj.ob_pd, pd_this->pd_pgmin_sym);
     return (x);
 }
 
@@ -294,7 +277,7 @@ static void pgmin_list(t_pgmin *x, t_symbol *s, int argc, t_atom *argv)
 
 static void pgmin_free(t_pgmin *x)
 {
-    pd_unbind(&x->x_obj.ob_pd, pgmin_sym);
+    pd_unbind(&x->x_obj.ob_pd, pd_this->pd_pgmin_sym);
 }
 
 static void pgmin_setup(void)
@@ -304,24 +287,21 @@ static void pgmin_setup(void)
             CLASS_NOINLET, A_DEFFLOAT, 0);
     class_addlist(pgmin_class, pgmin_list);
     class_sethelpsymbol(pgmin_class, gensym("midi"));
-    pgmin_sym = gensym("#pgmin");
 }
 
 void inmidi_programchange(int portno, int channel, int value)
 {
-    if (pgmin_sym->s_thing)
+    if (pd_this->pd_pgmin_sym->s_thing)
     {
         t_atom at[2];
         SETFLOAT(at, value + 1);
         SETFLOAT(at+1, (channel + (portno << 4) + 1));
-        pd_list(pgmin_sym->s_thing, &s_list, 2, at);
+        pd_list(pd_this->pd_pgmin_sym->s_thing, &s_list, 2, at);
     }
 }
 
 /* ----------------------- bendin ------------------------- */
 
-static t_symbol *bendin_sym;
-
 static t_class *bendin_class;
 
 typedef struct _bendin
@@ -338,7 +318,7 @@ static void *bendin_new(t_floatarg f)
     x->x_channel = f;
     x->x_outlet1 = outlet_new(&x->x_obj, &s_float);
     if (f == 0) x->x_outlet2 = outlet_new(&x->x_obj, &s_float);
-    pd_bind(&x->x_obj.ob_pd, bendin_sym);
+    pd_bind(&x->x_obj.ob_pd, pd_this->pd_bendin_sym);
     return (x);
 }
 
@@ -360,7 +340,7 @@ static void bendin_list(t_bendin *x, t_symbol *s, int argc, t_atom *argv)
 
 static void bendin_free(t_bendin *x)
 {
-    pd_unbind(&x->x_obj.ob_pd, bendin_sym);
+    pd_unbind(&x->x_obj.ob_pd, pd_this->pd_bendin_sym);
 }
 
 static void bendin_setup(void)
@@ -369,24 +349,21 @@ static void bendin_setup(void)
         (t_method)bendin_free, sizeof(t_bendin), CLASS_NOINLET, A_DEFFLOAT, 0);
     class_addlist(bendin_class, bendin_list);
     class_sethelpsymbol(bendin_class, gensym("midi"));
-    bendin_sym = gensym("#bendin");
 }
 
 void inmidi_pitchbend(int portno, int channel, int value)
 {
-    if (bendin_sym->s_thing)
+    if (pd_this->pd_bendin_sym->s_thing)
     {
         t_atom at[2];
         SETFLOAT(at, value);
         SETFLOAT(at+1, (channel + (portno << 4) + 1));
-        pd_list(bendin_sym->s_thing, &s_list, 2, at);
+        pd_list(pd_this->pd_bendin_sym->s_thing, &s_list, 2, at);
     }
 }
 
 /* ----------------------- touchin ------------------------- */
 
-static t_symbol *touchin_sym;
-
 static t_class *touchin_class;
 
 typedef struct _touchin
@@ -403,7 +380,7 @@ static void *touchin_new(t_floatarg f)
     x->x_channel = f;
     x->x_outlet1 = outlet_new(&x->x_obj, &s_float);
     if (f == 0) x->x_outlet2 = outlet_new(&x->x_obj, &s_float);
-    pd_bind(&x->x_obj.ob_pd, touchin_sym);
+    pd_bind(&x->x_obj.ob_pd, pd_this->pd_touchin_sym);
     return (x);
 }
 
@@ -425,7 +402,7 @@ static void touchin_list(t_touchin *x, t_symbol *s, int argc, t_atom *argv)
 
 static void touchin_free(t_touchin *x)
 {
-    pd_unbind(&x->x_obj.ob_pd, touchin_sym);
+    pd_unbind(&x->x_obj.ob_pd, pd_this->pd_touchin_sym);
 }
 
 static void touchin_setup(void)
@@ -435,24 +412,21 @@ static void touchin_setup(void)
             CLASS_NOINLET, A_DEFFLOAT, 0);
     class_addlist(touchin_class, touchin_list);
     class_sethelpsymbol(touchin_class, gensym("midi"));
-    touchin_sym = gensym("#touchin");
 }
 
 void inmidi_aftertouch(int portno, int channel, int value)
 {
-    if (touchin_sym->s_thing)
+    if (pd_this->pd_touchin_sym->s_thing)
     {
         t_atom at[2];
         SETFLOAT(at, value);
         SETFLOAT(at+1, (channel + (portno << 4) + 1));
-        pd_list(touchin_sym->s_thing, &s_list, 2, at);
+        pd_list(pd_this->pd_touchin_sym->s_thing, &s_list, 2, at);
     }
 }
 
 /* ----------------------- polytouchin ------------------------- */
 
-static t_symbol *polytouchin_sym;
-
 static t_class *polytouchin_class;
 
 typedef struct _polytouchin
@@ -471,7 +445,7 @@ static void *polytouchin_new(t_floatarg f)
     x->x_outlet1 = outlet_new(&x->x_obj, &s_float);
     x->x_outlet2 = outlet_new(&x->x_obj, &s_float);
     if (f == 0) x->x_outlet3 = outlet_new(&x->x_obj, &s_float);
-    pd_bind(&x->x_obj.ob_pd, polytouchin_sym);
+    pd_bind(&x->x_obj.ob_pd, pd_this->pd_polytouchin_sym);
     return (x);
 }
 
@@ -497,7 +471,7 @@ static void polytouchin_list(t_polytouchin *x, t_symbol *s, int argc,
 
 static void polytouchin_free(t_polytouchin *x)
 {
-    pd_unbind(&x->x_obj.ob_pd, polytouchin_sym);
+    pd_unbind(&x->x_obj.ob_pd, pd_this->pd_polytouchin_sym);
 }
 
 static void polytouchin_setup(void)
@@ -507,27 +481,24 @@ static void polytouchin_setup(void)
         sizeof(t_polytouchin), CLASS_NOINLET, A_DEFFLOAT, 0);
     class_addlist(polytouchin_class, polytouchin_list);
     class_sethelpsymbol(polytouchin_class, gensym("midi"));
-    polytouchin_sym = gensym("#polytouchin");
 }
 
 void inmidi_polyaftertouch(int portno, int channel, int pitch, int value)
 {
-    if (polytouchin_sym->s_thing)
+    if (pd_this->pd_polytouchin_sym->s_thing)
     {
         t_atom at[3];
         SETFLOAT(at, pitch);
         SETFLOAT(at+1, value);
         SETFLOAT(at+2, (channel + (portno << 4) + 1));
-        pd_list(polytouchin_sym->s_thing, &s_list, 3, at);
+        pd_list(pd_this->pd_polytouchin_sym->s_thing, &s_list, 3, at);
     }
 }
 
 /*----------------------- midiclkin--(midi F8 message )---------------------*/
-static t_symbol *midiclkin_sym;
 
 static t_class *midiclkin_class;
 
-
 typedef struct _midiclkin
 {
     t_object x_obj;
@@ -540,7 +511,7 @@ static void *midiclkin_new(t_floatarg f)
     t_midiclkin *x = (t_midiclkin *)pd_new(midiclkin_class);
     x->x_outlet1 = outlet_new(&x->x_obj, &s_float);
     x->x_outlet2 = outlet_new(&x->x_obj, &s_float);
-    pd_bind(&x->x_obj.ob_pd, midiclkin_sym);
+    pd_bind(&x->x_obj.ob_pd, pd_this->pd_midiclkin_sym);
     return (x);
 }
 
@@ -554,7 +525,7 @@ static void midiclkin_list(t_midiclkin *x, t_symbol *s, int argc, t_atom *argv)
 
 static void midiclkin_free(t_midiclkin *x)
 {
-    pd_unbind(&x->x_obj.ob_pd, midiclkin_sym);
+    pd_unbind(&x->x_obj.ob_pd, pd_this->pd_midiclkin_sym);
 }
 
 static void midiclkin_setup(void)
@@ -564,7 +535,6 @@ static void midiclkin_setup(void)
             sizeof(t_midiclkin), CLASS_NOINLET, A_DEFFLOAT, 0);
     class_addlist(midiclkin_class, midiclkin_list);
         class_sethelpsymbol(midiclkin_class, gensym("midi"));
-    midiclkin_sym = gensym("#midiclkin");
 }
 
 void inmidi_clk(double timing)
@@ -574,7 +544,7 @@ void inmidi_clk(double timing)
     static t_float count = 0;
     t_float cur,diff;
 
-    if (midiclkin_sym->s_thing)
+    if (pd_this->pd_midiclkin_sym->s_thing)
     {
         t_atom at[2];
         diff =timing - prev;
@@ -588,15 +558,13 @@ void inmidi_clk(double timing)
         else SETFLOAT(at, 0);
 
         SETFLOAT(at+1, diff);
-        pd_list(midiclkin_sym->s_thing, &s_list, 2, at);
+        pd_list(pd_this->pd_midiclkin_sym->s_thing, &s_list, 2, at);
         prev = timing;
     }
 }
 
 /*----------midirealtimein (midi FA,FB,FC,FF message )-----------------*/
 
-static t_symbol *midirealtimein_sym;
-
 static t_class *midirealtimein_class;
 
 typedef struct _midirealtimein
@@ -611,7 +579,7 @@ static void *midirealtimein_new( void)
     t_midirealtimein *x = (t_midirealtimein *)pd_new(midirealtimein_class);
     x->x_outlet1 = outlet_new(&x->x_obj, &s_float);
     x->x_outlet2 = outlet_new(&x->x_obj, &s_float);
-    pd_bind(&x->x_obj.ob_pd, midirealtimein_sym);
+    pd_bind(&x->x_obj.ob_pd, pd_this->pd_midirealtimein_sym);
     return (x);
 }
 
@@ -627,7 +595,7 @@ static void midirealtimein_list(t_midirealtimein *x, t_symbol *s,
 
 static void midirealtimein_free(t_midirealtimein *x)
 {
-    pd_unbind(&x->x_obj.ob_pd, midirealtimein_sym);
+    pd_unbind(&x->x_obj.ob_pd, pd_this->pd_midirealtimein_sym);
 }
 
 static void midirealtimein_setup(void)
@@ -637,17 +605,16 @@ static void midirealtimein_setup(void)
             sizeof(t_midirealtimein), CLASS_NOINLET, A_DEFFLOAT, 0);
     class_addlist(midirealtimein_class, midirealtimein_list);
         class_sethelpsymbol(midirealtimein_class, gensym("midi"));
-    midirealtimein_sym = gensym("#midirealtimein");
 }
 
 void inmidi_realtimein(int portno, int SysMsg)
 {
-    if (midirealtimein_sym->s_thing)
+    if (pd_this->pd_midirealtimein_sym->s_thing)
     {
         t_atom at[2];
         SETFLOAT(at, portno);
         SETFLOAT(at+1, SysMsg);
-        pd_list(midirealtimein_sym->s_thing, &s_list, 2, at);
+        pd_list(pd_this->pd_midirealtimein_sym->s_thing, &s_list, 2, at);
     }
 }
 
@@ -1284,6 +1251,10 @@ static void bag_setup(void)
     class_addmethod(bag_class, (t_method)bag_clear, gensym("clear"), 0);
 }
 
+void sys_setmidiprefix(const char *prefix)
+{
+}
+
 void x_midi_setup(void)
 {
     midiin_setup();
