@@ -33,11 +33,26 @@ static t_class *netsend_class;
 typedef struct _netsend
 {
     t_object x_obj;
-    int x_fd;
+    t_outlet *x_msgout;
+    t_outlet *x_connectout;
+    int x_sockfd;
     int x_protocol;
     int x_bin;
 } t_netsend;
 
+static t_class *netreceive_class;
+
+typedef struct _netreceive
+{
+    t_netsend x_ns;
+    int x_nconnections;
+    int x_sockfd;
+    int *x_connections;
+    int x_old;
+} t_netreceive;
+
+static void netreceive_notify(t_netreceive *x, int fd);
+
 static void *netsend_new(t_symbol *s, int argc, t_atom *argv)
 {
     t_netsend *x = (t_netsend *)pd_new(netsend_class);
@@ -68,10 +83,81 @@ static void *netsend_new(t_symbol *s, int argc, t_atom *argv)
         pd_error(x, "netsend: extra arguments ignored:");
         postatom(argc, argv); endpost();
     }
-    x->x_fd = -1;
+    x->x_sockfd = -1;
+    if (x->x_protocol == SOCK_STREAM)
+        x->x_msgout = outlet_new(&x->x_obj, &s_anything);
     return (x);
 }
 
+static void netsend_readbin(t_netsend *x, int fd)
+{
+    unsigned char inbuf[MAXPDSTRING];
+    int ret = recv(fd, inbuf, MAXPDSTRING, 0), i;
+    if (!x->x_msgout)
+    {
+        bug("netsend_readbin");
+        return;
+    }
+    if (ret <= 0)
+    {
+        if (ret < 0)
+            sys_sockerror("recv");
+        sys_rmpollfn(fd);
+        sys_closesocket(fd);
+        if (x->x_obj.ob_pd == netreceive_class)
+            netreceive_notify((t_netreceive *)x, fd);
+    }
+    else if (x->x_protocol == SOCK_DGRAM)
+    {
+        t_atom *ap = (t_atom *)alloca(ret * sizeof(t_atom));
+        for (i = 0; i < ret; i++)
+            SETFLOAT(ap+i, inbuf[i]);
+        outlet_list(x->x_msgout, 0, ret, ap);
+    }
+    else
+    {
+        for (i = 0; i < ret; i++)
+            outlet_float(x->x_msgout, inbuf[i]);
+    }
+}
+
+static void netsend_doit(void *z, t_binbuf *b)
+{
+    t_atom messbuf[1024];
+    t_netsend *x = (t_netsend *)z;
+    int msg, natom = binbuf_getnatom(b);
+    t_atom *at = binbuf_getvec(b);
+    for (msg = 0; msg < natom;)
+    {
+        int emsg;
+        for (emsg = msg; emsg < natom && at[emsg].a_type != A_COMMA
+            && at[emsg].a_type != A_SEMI; emsg++)
+                ;
+        if (emsg > msg)
+        {
+            int i;
+            for (i = msg; i < emsg; i++)
+                if (at[i].a_type == A_DOLLAR || at[i].a_type == A_DOLLSYM)
+            {
+                pd_error(x, "netreceive: got dollar sign in message");
+                goto nodice;
+            }
+            if (at[msg].a_type == A_FLOAT)
+            {
+                if (emsg > msg + 1)
+                    outlet_list(x->x_msgout, 0, emsg-msg, at + msg);
+                else outlet_float(x->x_msgout, at[msg].a_w.w_float);
+            }
+            else if (at[msg].a_type == A_SYMBOL)
+                outlet_anything(x->x_msgout, at[msg].a_w.w_symbol,
+                    emsg-msg-1, at + msg + 1);
+        }
+    nodice:
+        msg = emsg + 1;
+    }
+}
+
+
 static void netsend_connect(t_netsend *x, t_symbol *hostname,
     t_floatarg fportno)
 {
@@ -80,7 +166,7 @@ static void netsend_connect(t_netsend *x, t_symbol *hostname,
     int sockfd;
     int portno = fportno;
     int intarg;
-    if (x->x_fd >= 0)
+    if (x->x_sockfd >= 0)
     {
         error("netsend_connect: already connected");
         return;
@@ -136,83 +222,104 @@ static void netsend_connect(t_netsend *x, t_symbol *hostname,
         sys_closesocket(sockfd);
         return;
     }
-    x->x_fd = sockfd;
+    x->x_sockfd = sockfd;
+    if (x->x_msgout)    /* add polling function for return messages */
+    {
+        if (x->x_bin)
+            sys_addpollfn(sockfd, (t_fdpollfn)netsend_readbin, x);
+        else
+        {
+            t_socketreceiver *y =
+                socketreceiver_new((void *)x, 0, netsend_doit, 0);
+            sys_addpollfn(sockfd, (t_fdpollfn)socketreceiver_read, y);
+        }
+    }
     outlet_float(x->x_obj.ob_outlet, 1);
 }
 
 static void netsend_disconnect(t_netsend *x)
 {
-    if (x->x_fd >= 0)
+    if (x->x_sockfd >= 0)
     {
-        sys_closesocket(x->x_fd);
-        x->x_fd = -1;
+        sys_rmpollfn(x->x_sockfd);
+        sys_closesocket(x->x_sockfd);
+        x->x_sockfd = -1;
         outlet_float(x->x_obj.ob_outlet, 0);
     }
 }
 
-static void netsend_send(t_netsend *x, t_symbol *s, int argc, t_atom *argv)
+static int netsend_dosend(t_netsend *x, int sockfd,
+    t_symbol *s, int argc, t_atom *argv)
 {
-    if (x->x_fd >= 0)
+    char *buf, *bp;
+    int length, sent, fail = 0;
+    t_binbuf *b = 0;
+    if (x->x_bin)
     {
-        char *buf, *bp;
-        int length, sent;
-        t_binbuf *b = 0;
-        if (x->x_bin)
+        int i;
+        buf = alloca(argc);
+        for (i = 0; i < argc; i++)
+            ((unsigned char *)buf)[i] = atom_getfloatarg(i, argc, argv);
+        length = argc;
+    }
+    else
+    {
+        t_atom at;
+        b = binbuf_new();
+        binbuf_add(b, argc, argv);
+        SETSEMI(&at);
+        binbuf_add(b, 1, &at);
+        binbuf_gettext(b, &buf, &length);
+    }
+    for (bp = buf, sent = 0; sent < length;)
+    {
+        static double lastwarntime;
+        static double pleasewarn;
+        double timebefore = sys_getrealtime();
+        int res = send(sockfd, bp, length-sent, 0);
+        double timeafter = sys_getrealtime();
+        int late = (timeafter - timebefore > 0.005);
+        if (late || pleasewarn)
         {
-            int i;
-            buf = alloca(argc);
-            for (i = 0; i < argc; i++)
-                ((unsigned char *)buf)[i] = atom_getfloatarg(i, argc, argv);
-            length = argc;
+            if (timeafter > lastwarntime + 2)
+            {
+                 post("netsend/netreceive blocked %d msec",
+                    (int)(1000 * ((timeafter - timebefore) +
+                        pleasewarn)));
+                 pleasewarn = 0;
+                 lastwarntime = timeafter;
+            }
+            else if (late) pleasewarn += timeafter - timebefore;
+        }
+        if (res <= 0)
+        {
+            sys_sockerror("netsend");
+            fail = 1;
+            break;
         }
         else
         {
-            t_atom at;
-            b = binbuf_new();
-            binbuf_add(b, argc, argv);
-            SETSEMI(&at);
-            binbuf_add(b, 1, &at);
-            binbuf_gettext(b, &buf, &length);
-        }
-        for (bp = buf, sent = 0; sent < length;)
-        {
-            static double lastwarntime;
-            static double pleasewarn;
-            double timebefore = sys_getrealtime();
-            int res = send(x->x_fd, bp, length-sent, 0);
-            double timeafter = sys_getrealtime();
-            int late = (timeafter - timebefore > 0.005);
-            if (late || pleasewarn)
-            {
-                if (timeafter > lastwarntime + 2)
-                {
-                     post("netsend blocked %d msec",
-                        (int)(1000 * ((timeafter - timebefore) +
-                            pleasewarn)));
-                     pleasewarn = 0;
-                     lastwarntime = timeafter;
-                }
-                else if (late) pleasewarn += timeafter - timebefore;
-            }
-            if (res <= 0)
-            {
-                sys_sockerror("netsend");
-                netsend_disconnect(x);
-                break;
-            }
-            else
-            {
-                sent += res;
-                bp += res;
-            }
-        }
-        if (!x->x_bin)
-        {
-            t_freebytes(buf, length);
-            binbuf_free(b);
+            sent += res;
+            bp += res;
         }
     }
-    else error("netsend: not connected");
+    done:
+    if (!x->x_bin)
+    {
+        t_freebytes(buf, length);
+        binbuf_free(b);
+    }
+    return (fail);
+}
+
+
+static void netsend_send(t_netsend *x, t_symbol *s, int argc, t_atom *argv)
+{
+    if (x->x_sockfd >= 0)
+    {
+        if (netsend_dosend(x, x->x_sockfd, s, argc, argv))
+            netsend_disconnect(x);
+    }
 }
 
 static void netsend_free(t_netsend *x)
@@ -234,22 +341,6 @@ static void netsend_setup(void)
 }
 
 /* ----------------------------- netreceive ------------------------- */
-
-static t_class *netreceive_class;
-
-typedef struct _netreceive
-{
-    t_object x_obj;
-    t_outlet *x_msgout;
-    t_outlet *x_connectout;
-    int x_nconnections;
-    int x_udp;
-    int x_bin;
-    int x_sockfd;
-    int *x_connections;
-    int x_old;
-} t_netreceive;
-
 static void netreceive_notify(t_netreceive *x, int fd)
 {
     int i;
@@ -265,79 +356,12 @@ static void netreceive_notify(t_netreceive *x, int fd)
             x->x_nconnections--;
         }
     }
-    outlet_float(x->x_connectout, x->x_nconnections);
-}
-
-static void netreceive_readbin(t_netreceive *x, int fd)
-{
-    unsigned char inbuf[MAXPDSTRING];
-    int ret = recv(fd, inbuf, MAXPDSTRING, 0), i;
-    if (!x->x_msgout)
-    {
-        bug("netreceive_readbin");
-        return;
-    }
-    if (ret <= 0)
-    {
-        if (ret < 0)
-            sys_sockerror("recv");
-        sys_rmpollfn(fd);
-        sys_closesocket(fd);
-        netreceive_notify(x, fd);
-    }
-    else if (x->x_udp)
-    {
-        t_atom *ap = (t_atom *)alloca(ret * sizeof(t_atom));
-        for (i = 0; i < ret; i++)
-            SETFLOAT(ap+i, inbuf[i]);
-        outlet_list(x->x_msgout, 0, ret, ap);
-    }
-    else
-    {
-        for (i = 0; i < ret; i++)
-            outlet_float(x->x_msgout, inbuf[i]);
-    }
-}
-
-static void netreceive_doit(void *z, t_binbuf *b)
-{
-    t_atom messbuf[1024];
-    t_netreceive *x = (t_netreceive *)z;
-    int msg, natom = binbuf_getnatom(b);
-    t_atom *at = binbuf_getvec(b);
-    for (msg = 0; msg < natom;)
-    {
-        int emsg;
-        for (emsg = msg; emsg < natom && at[emsg].a_type != A_COMMA
-            && at[emsg].a_type != A_SEMI; emsg++)
-                ;
-        if (emsg > msg)
-        {
-            int i;
-            for (i = msg; i < emsg; i++)
-                if (at[i].a_type == A_DOLLAR || at[i].a_type == A_DOLLSYM)
-            {
-                pd_error(x, "netreceive: got dollar sign in message");
-                goto nodice;
-            }
-            if (at[msg].a_type == A_FLOAT)
-            {
-                if (emsg > msg + 1)
-                    outlet_list(x->x_msgout, 0, emsg-msg, at + msg);
-                else outlet_float(x->x_msgout, at[msg].a_w.w_float);
-            }
-            else if (at[msg].a_type == A_SYMBOL)
-                outlet_anything(x->x_msgout, at[msg].a_w.w_symbol,
-                    emsg-msg-1, at + msg + 1);
-        }
-    nodice:
-        msg = emsg + 1;
-    }
+    outlet_float(x->x_ns.x_connectout, x->x_nconnections);
 }
 
 static void netreceive_connectpoll(t_netreceive *x)
 {
-    int fd = accept(x->x_sockfd, 0, 0);
+    int fd = accept(x->x_ns.x_sockfd, 0, 0);
     if (fd < 0) post("netreceive: accept failed");
     else
     {
@@ -346,16 +370,16 @@ static void netreceive_connectpoll(t_netreceive *x)
         x->x_connections = (int *)t_resizebytes(x->x_connections,
             x->x_nconnections * sizeof(int), nconnections * sizeof(int));
         x->x_connections[x->x_nconnections] = fd;
-        if (x->x_bin)
-            sys_addpollfn(fd, (t_fdpollfn)netreceive_readbin, x);
+        if (x->x_ns.x_bin)
+            sys_addpollfn(fd, (t_fdpollfn)netsend_readbin, x);
         else
         {
             t_socketreceiver *y = socketreceiver_new((void *)x, 
             (t_socketnotifier)netreceive_notify,
-                (x->x_msgout ? netreceive_doit : 0), 0);
+                (x->x_ns.x_msgout ? netsend_doit : 0), 0);
             sys_addpollfn(fd, (t_fdpollfn)socketreceiver_read, y);
         }
-        outlet_float(x->x_connectout, (x->x_nconnections = nconnections));
+        outlet_float(x->x_ns.x_connectout, (x->x_nconnections = nconnections));
     }
 }
 
@@ -370,12 +394,12 @@ static void netreceive_closeall(t_netreceive *x)
     x->x_connections = (int *)t_resizebytes(x->x_connections, 
         x->x_nconnections * sizeof(int), 0);
     x->x_nconnections = 0;
-    if (x->x_sockfd >= 0)
+    if (x->x_ns.x_sockfd >= 0)
     {
-        sys_rmpollfn(x->x_sockfd);
-        sys_closesocket(x->x_sockfd);
+        sys_rmpollfn(x->x_ns.x_sockfd);
+        sys_closesocket(x->x_ns.x_sockfd);
     }
-    x->x_sockfd = -1;
+    x->x_ns.x_sockfd = -1;
 }
 
 static void netreceive_listen(t_netreceive *x, t_floatarg fportno)
@@ -385,8 +409,8 @@ static void netreceive_listen(t_netreceive *x, t_floatarg fportno)
     netreceive_closeall(x);
     if (portno <= 0)
         return;
-    x->x_sockfd = socket(AF_INET, (x->x_udp ? SOCK_DGRAM : SOCK_STREAM), 0);
-    if (x->x_sockfd < 0)
+    x->x_ns.x_sockfd = socket(AF_INET, x->x_ns.x_protocol, 0);
+    if (x->x_ns.x_sockfd < 0)
     {
         sys_sockerror("socket");
         return;
@@ -398,25 +422,25 @@ static void netreceive_listen(t_netreceive *x, t_floatarg fportno)
 #if 1
         /* ask OS to allow another Pd to repoen this port after we close it. */
     intarg = 1;
-    if (setsockopt(x->x_sockfd, SOL_SOCKET, SO_REUSEADDR,
+    if (setsockopt(x->x_ns.x_sockfd, SOL_SOCKET, SO_REUSEADDR,
         (char *)&intarg, sizeof(intarg)) < 0)
             post("netreceive: setsockopt (SO_REUSEADDR) failed\n");
 #endif
 #if 0
     intarg = 0;
-    if (setsockopt(x->x_sockfd, SOL_SOCKET, SO_RCVBUF,
+    if (setsockopt(x->x_ns.x_sockfd, SOL_SOCKET, SO_RCVBUF,
         &intarg, sizeof(intarg)) < 0)
             post("setsockopt (SO_RCVBUF) failed\n");
 #endif
     intarg = 1;
-    if (setsockopt(x->x_sockfd, SOL_SOCKET, SO_BROADCAST, 
+    if (setsockopt(x->x_ns.x_sockfd, SOL_SOCKET, SO_BROADCAST, 
         (const void *)&intarg, sizeof(intarg)) < 0)
             post("netreceive: failed to sett SO_BROADCAST");
         /* Stream (TCP) sockets are set NODELAY */
-    if (!x->x_udp)
+    if (x->x_ns.x_protocol == SOCK_STREAM)
     {
         intarg = 1;
-        if (setsockopt(x->x_sockfd, IPPROTO_TCP, TCP_NODELAY,
+        if (setsockopt(x->x_ns.x_sockfd, IPPROTO_TCP, TCP_NODELAY,
             (char *)&intarg, sizeof(intarg)) < 0)
                 post("setsockopt (TCP_NODELAY) failed\n");
     }
@@ -426,57 +450,71 @@ static void netreceive_listen(t_netreceive *x, t_floatarg fportno)
     server.sin_port = htons((u_short)portno);
 
         /* name the socket */
-    if (bind(x->x_sockfd, (struct sockaddr *)&server, sizeof(server)) < 0)
+    if (bind(x->x_ns.x_sockfd, (struct sockaddr *)&server, sizeof(server)) < 0)
     {
         sys_sockerror("bind");
-        sys_closesocket(x->x_sockfd);
-        x->x_sockfd = -1;
+        sys_closesocket(x->x_ns.x_sockfd);
+        x->x_ns.x_sockfd = -1;
         return;
     }
 
-    if (x->x_udp)        /* datagram protocol */
+    if (x->x_ns.x_protocol == SOCK_DGRAM)        /* datagram protocol */
     {
-        if (x->x_bin)
-            sys_addpollfn(x->x_sockfd, (t_fdpollfn)netreceive_readbin, x);
+        if (x->x_ns.x_bin)
+            sys_addpollfn(x->x_ns.x_sockfd, (t_fdpollfn)netsend_readbin, x);
         else
         {
             t_socketreceiver *y = socketreceiver_new((void *)x, 
                 (t_socketnotifier)netreceive_notify,
-                    (x->x_msgout ? netreceive_doit : 0), 1);
-            sys_addpollfn(x->x_sockfd, (t_fdpollfn)socketreceiver_read, y);
-            x->x_connectout = 0;
+                    (x->x_ns.x_msgout ? netsend_doit : 0), 1);
+            sys_addpollfn(x->x_ns.x_sockfd, (t_fdpollfn)socketreceiver_read, y);
+            x->x_ns.x_connectout = 0;
         }
     }
     else        /* streaming protocol */
     {
-        if (listen(x->x_sockfd, 5) < 0)
+        if (listen(x->x_ns.x_sockfd, 5) < 0)
         {
             sys_sockerror("listen");
-            sys_closesocket(x->x_sockfd);
-            x->x_sockfd = -1;
+            sys_closesocket(x->x_ns.x_sockfd);
+            x->x_ns.x_sockfd = -1;
         }
         else
         {
-            sys_addpollfn(x->x_sockfd, (t_fdpollfn)netreceive_connectpoll, x);
-            x->x_connectout = outlet_new(&x->x_obj, &s_float);
+            sys_addpollfn(x->x_ns.x_sockfd, (t_fdpollfn)netreceive_connectpoll, x);
+            x->x_ns.x_connectout = outlet_new(&x->x_ns.x_obj, &s_float);
         }
     }
 }
 
+
+static void netreceive_send(t_netreceive *x, 
+    t_symbol *s, int argc, t_atom *argv)
+{
+    int i;
+    for (i = 0; i < x->x_nconnections; i++)
+    {
+        if (netsend_dosend(&x->x_ns, x->x_connections[i], s, argc, argv))
+            pd_error(x, "netreceive send message failed");
+                /* should we now close the connection? */
+    }
+}
+
 static void *netreceive_new(t_symbol *s, int argc, t_atom *argv)
 {
     t_netreceive *x = (t_netreceive *)pd_new(netreceive_class);
     int portno = 0;
-    x->x_udp = 0;
+    x->x_ns.x_protocol = SOCK_STREAM;
     x->x_old = 0;
-    x->x_bin = 0;
+    x->x_ns.x_bin = 0;
     x->x_nconnections = 0;
     x->x_connections = (int *)t_getbytes(0);
-    x->x_sockfd = -1;
+    x->x_ns.x_sockfd = -1;
     if (argc && argv->a_type == A_FLOAT)
     {
         portno = atom_getfloatarg(0, argc, argv);
-        x->x_udp = (atom_getfloatarg(1, argc, argv) != 0);
+        x->x_ns.x_protocol = (atom_getfloatarg(1, argc, argv) != 0 ?
+            SOCK_DGRAM : SOCK_STREAM);
         x->x_old = (!strcmp(atom_getsymbolarg(2, argc, argv)->s_name, "old"));
         argc = 0;
     }
@@ -486,9 +524,9 @@ static void *netreceive_new(t_symbol *s, int argc, t_atom *argv)
             *argv->a_w.w_symbol->s_name == '-')
         {
             if (!strcmp(argv->a_w.w_symbol->s_name, "-b"))
-                x->x_bin = 1;
+                x->x_ns.x_bin = 1;
             else if (!strcmp(argv->a_w.w_symbol->s_name, "-u"))
-                x->x_udp = 1;
+                x->x_ns.x_protocol = SOCK_DGRAM;
             else
             {
                 pd_error(x, "netreceive: unknown flag ...");
@@ -507,9 +545,9 @@ static void *netreceive_new(t_symbol *s, int argc, t_atom *argv)
     if (x->x_old)
     {
         /* old style, nonsecure version */
-        x->x_msgout = 0;
+        x->x_ns.x_msgout = 0;
     }
-    else x->x_msgout = outlet_new(&x->x_obj, &s_anything);
+    else x->x_ns.x_msgout = outlet_new(&x->x_ns.x_obj, &s_anything);
         /* create a socket */
     if (portno > 0)
         netreceive_listen(x, portno);
@@ -524,6 +562,8 @@ static void netreceive_setup(void)
         sizeof(t_netreceive), 0, A_GIMME, 0);
     class_addmethod(netreceive_class, (t_method)netreceive_listen,
         gensym("listen"), A_FLOAT, 0);
+    class_addmethod(netreceive_class, (t_method)netreceive_send,
+        gensym("send"), A_GIMME, 0);
 }
 
 void x_net_setup(void)
